@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -121,7 +121,7 @@ public:
    *
    * @copydetails doc_note_setting_lv
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   ListOf (unsigned int level   = SBML_DEFAULT_LEVEL,
           unsigned int version = SBML_DEFAULT_VERSION);
@@ -173,9 +173,9 @@ public:
 
 
   /**
-   * Creates and returns a deep copy of this ListOf.
+   * Creates and returns a deep copy of this ListOf object.
    *
-   * @return a (deep) copy of this ListOf.
+   * @return the (deep) copy of this ListOf object.
    */
   virtual ListOf* clone () const;
 
@@ -186,18 +186,15 @@ public:
    * This method makes a clone of the @p item handed to it.  This means that
    * when the ListOf object is destroyed, the original items will not be
    * destroyed.  For a method with an alternative ownership behavior, see the
-   * ListOf::appendAndOwn(@if java SBase* item@endif) method.
+   * ListOf::appendAndOwn(@if java SBase@endif) method.
    *
    * @param item the item to be added to the list.
    *
-   * @return integer value indicating success/failure of the
-   * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif@~ The possible values
-   * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
    *
-   * @see appendAndOwn(SBase* item)
+   * @see appendAndOwn(SBase* disownedItem)
    * @see appendFrom(const ListOf* list)
    */
   int append (const SBase* item);
@@ -206,24 +203,21 @@ public:
   /**
    * Adds an item to the end of this ListOf's list of items.
    *
-   * This method does not clone the @p item handed to it; instead, it assumes
+   * This method does not clone the @p disownedItem handed to it; instead, it assumes
    * ownership of it.  This means that when the ListOf is destroyed, the item
    * will be destroyed along with it.  For a method with an alternative
    * ownership behavior, see the ListOf::append(SBase* item) method.
    *
-   * @param item the item to be added to the list.
+   * @param disownedItem the item to be added to the list.
    *
-   * @return integer value indicating success/failure of the
-   * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif@~ The possible values
-   * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
    *
    * @see append(const SBase* item)
    * @see appendFrom(const ListOf* list)
    */
-  int appendAndOwn (SBase* item);
+  int appendAndOwn (SBase* disownedItem);
 
 
   /**
@@ -234,15 +228,12 @@ public:
    *
    * @param list a list of items to be added.
    *
-   * @return integer value indicating success/failure of the
-   * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif@~ The possible values
-   * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
    *
    * @see append(const SBase* item)
-   * @see appendAndOwn(SBase* item)
+   * @see appendAndOwn(SBase* disownedItem)
    */
   virtual int appendFrom (const ListOf* list);
 
@@ -257,12 +248,9 @@ public:
    * @param location the location in the list where to insert the item.
    * @param item the item to be inserted to the list.
    *
-   * @return integer value indicating success/failure of the
-   * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif@~ The possible values
-   * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
    *
    * @see insertAndOwn(int location, SBase* item)
    */
@@ -272,23 +260,20 @@ public:
   /**
    * Inserts an item at a given position in this ListOf's list of items.
    *
-   * This variant of the method makes a clone of the @p item handed to it.
+   * This variant of the method does not make a clone of the @p disownedItem handed to it.
    * This means that when the ListOf is destroyed, the original @p item
    * <em>will</em> be destroyed.
    *
    * @param location the location where to insert the item
-   * @param item the item to be inserted to the list
+   * @param disownedItem the item to be inserted to the list
    *
-   * @return integer value indicating success/failure of the
-   * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif@~ The possible values
-   * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
-   * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
    *
    * @see insert(int location, const SBase* item)
    */
-  int insertAndOwn(int location, SBase* item);
+  int insertAndOwn(int location, SBase* disownedItem);
 
 
   /**
@@ -400,7 +385,7 @@ public:
    * @param doDelete if @c true (default), all items are deleted and cleared.
    * Otherwise, all items are just cleared and not deleted.
    *
-   * @if notcpp @htmlinclude warn-default-args-in-docs.html @endif@~
+   * @ifnot hasDefaultArgs @htmlinclude warn-default-args-in-docs.html @endif@~
    */
   void clear (bool doDelete = true);
 
@@ -416,11 +401,8 @@ public:
    * @if cpp Implementations of subclasses of ListOf may need to override
    * this method if different handling of child objects is needed.@endif@~
    *
-   * @return integer value indicating success/failure of the
-   * function.  @if clike The value is drawn from the
-   * enumeration #OperationReturnValues_t. @endif@~ The possible values
-   * returned by this function are:
-   * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
    */
   virtual int removeFromParentAndDelete();
 
@@ -495,12 +477,12 @@ public:
 
   /**
    * Returns the libSBML type code for this object, namely,
-   * @link SBMLTypeCode_t#SBML_LIST_OF SBML_LIST_OF@endlink.
+   * @sbmlconstant{SBML_LIST_OF, SBMLTypeCode_t}.
    * 
    * @copydetails doc_what_are_typecodes
    *
    * @return the SBML type code for this object:
-   * @link SBMLTypeCode_t#SBML_LIST_OF SBML_LIST_OF@endlink (default).
+   * @sbmlconstant{SBML_LIST_OF, SBMLTypeCode_t} (default).
    *
    * @note The various ListOf classes mostly differ from each other in what they
    * contain.  Hence, one must call getItemTypeCode() to fully determine the
@@ -523,10 +505,10 @@ public:
    * Classes that inherit from the ListOf class should override this method
    * to return the SBML type code for the objects contained in this ListOf.
    * If they do not, this method will return
-   * @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink
+   * @sbmlconstant{SBML_UNKNOWN, SBMLTypeCode_t}
    *
    * @return The ListOf base class contains no SBML objects, and therefore
-   * this method returns @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink.
+   * this method returns @sbmlconstant{SBML_UNKNOWN, SBMLTypeCode_t}.
    *
    * @see getElementName()
    * @see getPackageName()
@@ -601,7 +583,7 @@ protected:
    */
   virtual void writeAttributes (XMLOutputStream& stream) const;
 
-  virtual bool isValidTypeForList(SBase * item) {return item->getTypeCode() == getItemTypeCode();}
+  virtual bool isValidTypeForList(SBase * item);
 
   ListItem mItems;
 
@@ -676,11 +658,9 @@ ListOf_clone (const ListOf_t *lo);
  * @param lo the ListOf_t structure to which the @p item should be appended.
  * @param item the item to append to the list.
  *
- * @return integer value indicating success/failure of the function. The
- * value is drawn from the enumeration #OperationReturnValues_t. The possible
- * values returned by this function are:
- * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
- * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
  *
  * @see ListOf_appendAndOwn()
  *
@@ -694,17 +674,15 @@ ListOf_append (ListOf_t *lo, const SBase_t *item);
 /**
  * Adds the given item to the end of a ListOf_t list.
  *
- * @param lo the ListOf_t structure to which the @p item should be appended.
- * @param item the item to append to the list.
+ * @param lo the ListOf_t structure to which the @p disownedItem should be appended.
+ * @param disownedItem the item to append to the list.
  *
- * Unlike ListOf_append(), this function does not copy the @p item.
+ * Unlike ListOf_append(), this function does not copy the @p disownedItem.
  * The given @p lo list will contain the original item.
  *
- * @return integer value indicating success/failure of the function. The
- * value is drawn from the enumeration #OperationReturnValues_t. The possible
- * values returned by this function are:
- * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
- * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
  *
  * @see ListOf_append()
  *
@@ -712,7 +690,7 @@ ListOf_append (ListOf_t *lo, const SBase_t *item);
  */
 LIBSBML_EXTERN
 int
-ListOf_appendAndOwn (ListOf_t *lo, SBase_t *item);
+ListOf_appendAndOwn (ListOf_t *lo, SBase_t *disownedItem);
 
 
 /**
@@ -721,11 +699,9 @@ ListOf_appendAndOwn (ListOf_t *lo, SBase_t *item);
  * @param lo the ListOf_t list to which @p list will be appended.
  * @param list the list of items to append to @p lo.
  *
- * @return integer value indicating success/failure of the function. The
- * value is drawn from the enumeration #OperationReturnValues_t. The possible
- * values returned by this function are:
- * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
- * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
  *
  * @memberof ListOf_t
  */
@@ -741,11 +717,9 @@ ListOf_appendFrom (ListOf_t *lo, ListOf_t *list);
  * @param location the starting index for the @p item in the @p lo list.
  * @param item the item to append to insert into @p lo.
  *
- * @return integer value indicating success/failure of the function. The
- * value is drawn from the enumeration #OperationReturnValues_t. The possible
- * values returned by this function are:
- * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
- * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
  *
  * @memberof ListOf_t
  */
@@ -757,24 +731,22 @@ ListOf_insert (ListOf_t *lo, int location, const SBase_t *item);
 /**
  * Inserts an item into a ListOf_t list at a given position.
  *
- * Unlike ListOf_insert(), this function does not clone @p item before
+ * Unlike ListOf_insert(), this function does not clone @p disownedItem before
  * inserting it into @p lo, which means that @p lo becomes the owner.
  *
- * @param lo the list into which @p item will be inserted.
- * @param location the starting index for the @p item in the @p lo list.
- * @param item the item to append to insert into @p lo.
+ * @param lo the list into which @p disownedItem will be inserted.
+ * @param location the starting index for the @p disownedItem in the @p lo list.
+ * @param disownedItem the item to append to insert into @p lo.
  *
- * @return integer value indicating success/failure of the function. The
- * value is drawn from the enumeration #OperationReturnValues_t. The possible
- * values returned by this function are:
- * @li @link OperationReturnValues_t#LIBSBML_OPERATION_SUCCESS LIBSBML_OPERATION_SUCCESS@endlink
- * @li @link OperationReturnValues_t#LIBSBML_INVALID_OBJECT LIBSBML_INVALID_OBJECT@endlink
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
  *
  * @memberof ListOf_t
  */
 LIBSBML_EXTERN
 int
-ListOf_insertAndOwn (ListOf_t *lo, int location, SBase_t *item);
+ListOf_insertAndOwn (ListOf_t *lo, int location, SBase_t *disownedItem);
 
 
 /**
@@ -883,7 +855,7 @@ ListOf_size (const ListOf_t *lo);
  * @param lo the ListOf_t whose item type codes are sought.
  *
  * @return the type code corresponding to the objects in @p lo,
- * or @link SBMLTypeCode_t#SBML_UNKNOWN SBML_UNKNOWN@endlink.
+ * or @sbmlconstant{SBML_UNKNOWN, SBMLTypeCode_t}.
  *
  * @memberof ListOf_t
  */
