@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -355,6 +355,9 @@ public:
   virtual bool isSetConstant () const;
 
   virtual int setConstant (bool flag);
+
+  virtual int unsetConstant();
+
   /** @endcond */
 
 protected:
@@ -1022,6 +1025,25 @@ int
 LocalParameter_unsetUnits (LocalParameter_t *p);
 
 
+/**
+ * Because LocalParameter_t structures don't have a 'constant' attribute, this function always
+ * returns @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}.
+ *
+ * @param p the LocalParameter_t structure to leave unchanged.
+ *
+ * @return integer value indicating success/failure of the
+ * function.  @if clike The value is drawn from the
+ * enumeration #OperationReturnValues_t. @endif@~ The possible value
+ * returned by this function is:
+ * @li @sbmlconstant{LIBSBML_INVALID_ATTRIBUTE_VALUE, OperationReturnValues_t}
+ *
+ * @memberof LocalParameter_t
+ */
+LIBSBML_EXTERN
+int
+LocalParameter_unsetConstant (LocalParameter_t *p);
+
+
 /**
  * Predicate returning @c true or @c false depending on whether
  * all the required attributes for this LocalParameter object
