@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -304,6 +304,14 @@ ModifierSpeciesReference_unsetName(ModifierSpeciesReference_t * msr)
 }
 
 
+LIBSBML_EXTERN
+int
+ModifierSpeciesReference_unsetSpecies(ModifierSpeciesReference_t * msr)
+{
+  return (msr != NULL) ? msr->unsetSpecies() : LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 ModifierSpeciesReference_hasRequiredAttributes(const ModifierSpeciesReference_t * msr)
