@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -526,6 +526,20 @@ public:
   virtual int unsetName ();
 
 
+  /**
+   * Unsets the value of the "constant" attribute of this Parameter object.
+   *
+   * @copydetails doc_returns_success_code
+   * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+   * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+   *
+   * @see isSetConstant()
+   * @see setConstant(@if java String@endif)
+   * @see getConstant()
+   */
+  int unsetConstant ();
+
+
   /**
    * Unsets the "value" attribute of this Parameter instance.
    *
@@ -1385,6 +1399,24 @@ int
 Parameter_unsetName (Parameter_t *p);
 
 
+/**
+ * Unsets the value of the "constant" attribute of the given Parameter_t
+ * structure.
+ *
+ * @param c the Parameter_t structure.
+ *
+ * @copydetails doc_returns_success_code
+ * @li @sbmlconstant{LIBSBML_OPERATION_SUCCESS, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_OPERATION_FAILED, OperationReturnValues_t}
+ * @li @sbmlconstant{LIBSBML_INVALID_OBJECT, OperationReturnValues_t}
+ *
+ * @memberof Parameter_t
+ */
+LIBSBML_EXTERN
+int
+Parameter_unsetConstant (Parameter_t *c);
+
+
 /**
  * Unsets the value of this Parameter_t structure.
  *
