@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -279,6 +279,15 @@ RateRule_setFormula (RateRule_t *r, const char *formula)
 }
 
 
+LIBSBML_EXTERN
+int
+RateRule_unsetVariable(RateRule_t * ar)
+{
+  return (ar != NULL) ? static_cast<int>(ar->unsetVariable()) 
+                      : LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 RateRule_hasRequiredAttributes(const RateRule_t * rr)
