@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -358,10 +363,9 @@ Reaction::renameSIdRefs(const std::string& oldid, const std::string& newid)
 void
 Reaction::initDefaults ()
 {
-  //// level 3 has no defaults
-  //if (getLevel() < 3)
-  //{
-    setReversible(true);
+  setReversible(true);
+  // not explicilty set
+  mExplicitlySetReversible = false;
 
   //
   // Set fast explicitly and make sure mIsSetFast is false.  This preserves
@@ -375,13 +379,14 @@ Reaction::initDefaults ()
   //   r.isSetFast() == N/A             r.isSetFast() == false
   //
   // but for L3 acknowledge that fast has been set
-    mFast      = false;
-    mIsSetFast = false;
-    if (getLevel() == 3)
-    {
-      setFast(false);
-    }
-  //}
+  mFast      = false;
+  mIsSetFast = false;
+  if (getLevel() == 3)
+  {
+    setFast(false);
+  }
+
+  mExplicitlySetFast = false;
 }
 
 
@@ -776,6 +781,29 @@ Reaction::unsetCompartment ()
 }
 
 
+/*
+ * Unsets the reversible status of this Reaction.
+ */
+int
+Reaction::unsetReversible ()
+{
+  if (getLevel() < 3)
+  {
+    // reset default
+    mReversible = true;
+    mIsSetReversible = true;
+    mExplicitlySetReversible = false;
+    return LIBSBML_UNEXPECTED_ATTRIBUTE;
+  }
+  else
+  {
+    mIsSetReversible = false;
+    mExplicitlySetReversible = false;
+    return LIBSBML_OPERATION_SUCCESS;
+  }
+}
+
+
 /*
  * Adds a copy of the given reactant (SpeciesReference) to this Reaction.
  */
@@ -1559,7 +1587,8 @@ Reaction::readL1Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("name", level, version, "<reaction>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // reversible: boolean  { use="optional"  default="true" }
@@ -1597,7 +1626,8 @@ Reaction::readL2Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<reaction>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
   //
   // reversible: boolean  { use="optional"  default="true" }
@@ -1653,8 +1683,13 @@ Reaction::readL3Attributes (const XMLAttributes& attributes)
   {
     logEmptyString("id", level, version, "<reaction>");
   }
-  if (!SyntaxChecker::isValidInternalSId(mId)) logError(InvalidIdSyntax);
+  if (!SyntaxChecker::isValidInternalSId(mId)) 
+    logError(InvalidIdSyntax, level, version, "The id '" + mId + "' does not conform to the syntax.");
 
+  string elplusid = "<reaction>";
+  if (!mId.empty()) {
+    elplusid += " with the id '" + mId + "'";
+  }
   //
   // reversible: boolean  { use="required"} (L3v1->)
   //
@@ -1663,7 +1698,8 @@ Reaction::readL3Attributes (const XMLAttributes& attributes)
   if (!mIsSetReversible)
   {
     logError(AllowedAttributesOnReaction, level, version, 
-                "The required attribute 'reversible' is missing.");
+                "The required attribute 'reversible' is missing from the "
+                + elplusid + ".");
   }
 
   //
@@ -1674,7 +1710,8 @@ Reaction::readL3Attributes (const XMLAttributes& attributes)
   if (!mIsSetFast)
   {
     logError(AllowedAttributesOnReaction, level, version, 
-      "The required attribute 'fast' is missing.");
+      "The required attribute 'fast' is missing from the "
+                + elplusid + ".");
   }
 
   //
@@ -1692,7 +1729,8 @@ Reaction::readL3Attributes (const XMLAttributes& attributes)
   }
   if (!SyntaxChecker::isValidInternalSId(mCompartment)) 
     logError(InvalidIdSyntax, getLevel(), getVersion(), 
-    "The syntax of the attribute compartment='" + mCompartment + "' does not conform.");
+      "The " + elplusid + " has a 'compartment' with a value of '" + mCompartment 
+      + "' which does not conform .");
 }
 /** @endcond */
 
@@ -1985,29 +2023,9 @@ ListOfReactions::createObject (XMLInputStream& stream)
 #endif /* __cplusplus */
 
 
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
-/**
- * Creates a new Reaction_t structure using the given SBML @p level
- * and @p version values.
- *
- * @param level an unsigned int, the SBML Level to assign to this
- * Reaction
- *
- * @param version an unsigned int, the SBML Version to assign to this
- * Reaction
- *
- * @return a pointer to the newly created Reaction_t structure.
- *
- * @note Once a Reaction has been added to an SBMLDocument, the @p
- * level and @p version for the document @em override those used to create
- * the Reaction.  Despite this, the ability to supply the values at
- * creation time is an important aid to creating valid SBML.  Knowledge of
- * the intended SBML Level and Version  determine whether it is valid to
- * assign a particular value to an attribute, or whether it is valid to add
- * an object to an existing SBMLDocument.
- */
 LIBSBML_EXTERN
 Reaction_t *
 Reaction_create (unsigned int level, unsigned int version)
@@ -2024,23 +2042,6 @@ Reaction_create (unsigned int level, unsigned int version)
 }
 
 
-/**
- * Creates a new Reaction_t structure using the given
- * SBMLNamespaces_t structure.
- *
- * @param sbmlns SBMLNamespaces, a pointer to an SBMLNamespaces structure
- * to assign to this Reaction
- *
- * @return a pointer to the newly created Reaction_t structure.
- *
- * @note Once a Reaction has been added to an SBMLDocument, the
- * @p sbmlns namespaces for the document @em override those used to create
- * the Reaction.  Despite this, the ability to supply the values at creation 
- * time is an important aid to creating valid SBML.  Knowledge of the intended 
- * SBML Level and Version determine whether it is valid to assign a particular 
- * value to an attribute, or whether it is valid to add an object to an 
- * existing SBMLDocument.
- */
 LIBSBML_EXTERN
 Reaction_t *
 Reaction_createWithNS (SBMLNamespaces_t* sbmlns)
@@ -2056,9 +2057,6 @@ Reaction_createWithNS (SBMLNamespaces_t* sbmlns)
   }
 }
 
-/**
- * Frees the given Reaction.
- */
 LIBSBML_EXTERN
 void
 Reaction_free (Reaction_t *r)
@@ -2067,9 +2065,6 @@ Reaction_free (Reaction_t *r)
 }
 
 
-/**
- * @return a (deep) copy of this Reaction.
- */
 LIBSBML_EXTERN
 Reaction_t *
 Reaction_clone (const Reaction_t *r)
@@ -2078,12 +2073,6 @@ Reaction_clone (const Reaction_t *r)
 }
 
 
-/**
- * Initializes the fields of this Reaction to their defaults:
- *
- *   - reversible = 1 (true)
- *   - fast       = 0 (false)  (L1 only)
- */
 LIBSBML_EXTERN
 void
 Reaction_initDefaults (Reaction_t *r)
@@ -2093,15 +2082,6 @@ Reaction_initDefaults (Reaction_t *r)
 }
 
 
-/**
- * Returns a list of XMLNamespaces_t associated with this Reaction_t
- * structure.
- *
- * @param r the Reaction_t structure
- * 
- * @return pointer to the XMLNamespaces_t structure associated with 
- * this SBML object
- */
 LIBSBML_EXTERN
 const XMLNamespaces_t *
 Reaction_getNamespaces(Reaction_t *r)
@@ -2109,9 +2089,6 @@ Reaction_getNamespaces(Reaction_t *r)
   return (r != NULL) ? r->getNamespaces() : NULL;
 }
 
-/**
- * @return the id of this Reaction.
- */
 LIBSBML_EXTERN
 const char *
 Reaction_getId (const Reaction_t *r)
@@ -2120,9 +2097,6 @@ Reaction_getId (const Reaction_t *r)
 }
 
 
-/**
- * @return the name of this Reaction.
- */
 LIBSBML_EXTERN
 const char *
 Reaction_getName (const Reaction_t *r)
@@ -2131,9 +2105,6 @@ Reaction_getName (const Reaction_t *r)
 }
 
 
-/**
- * @return the KineticLaw of this Reaction.
- */
 LIBSBML_EXTERN
 KineticLaw_t *
 Reaction_getKineticLaw (Reaction_t *r)
@@ -2142,9 +2113,6 @@ Reaction_getKineticLaw (Reaction_t *r)
 }
 
 
-/**
- * @return the reversible status of this Reaction.
- */
 LIBSBML_EXTERN
 int
 Reaction_getReversible (const Reaction_t *r)
@@ -2153,9 +2121,6 @@ Reaction_getReversible (const Reaction_t *r)
 }
 
 
-/**
- * @return the fast status of this Reaction.
- */
 LIBSBML_EXTERN
 int
 Reaction_getFast (const Reaction_t *r)
@@ -2164,9 +2129,6 @@ Reaction_getFast (const Reaction_t *r)
 }
 
 
-/**
- * @return the compartment of this Reaction.
- */
 LIBSBML_EXTERN
 const char *
 Reaction_getCompartment (const Reaction_t *r)
@@ -2176,10 +2138,6 @@ Reaction_getCompartment (const Reaction_t *r)
 }
 
 
-/**
- * @return true (non-zero) if the id of this Reaction is set, false
- * (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 Reaction_isSetId (const Reaction_t *r)
@@ -2188,10 +2146,6 @@ Reaction_isSetId (const Reaction_t *r)
 }
 
 
-/**
- * @return true (non-zero) if the name of this Reaction is set, false
- * (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 Reaction_isSetName (const Reaction_t *r)
@@ -2200,10 +2154,6 @@ Reaction_isSetName (const Reaction_t *r)
 }
 
 
-/**
- * @return true (non-zero) if the KineticLaw of this Reaction is set,
- * false (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 Reaction_isSetKineticLaw (const Reaction_t *r)
@@ -2212,14 +2162,6 @@ Reaction_isSetKineticLaw (const Reaction_t *r)
 }
 
 
-/**
- * @return true (non-zero) if the fast status of this Reaction is set,
- * false (0) otherwise.
- *
- * In L1, fast is optional with a default of false, which means it is
- * effectively always set.  In L2, however, fast is optional with no
- * default value, so it may or may not be set to a specific value.
- */
 LIBSBML_EXTERN
 int
 Reaction_isSetFast (const Reaction_t *r)
@@ -2228,10 +2170,6 @@ Reaction_isSetFast (const Reaction_t *r)
 }
 
 
-/**
- * @return true (non-zero) if the KineticLaw of this Reaction is set,
- * false (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 Reaction_isSetCompartment (const Reaction_t *r)
@@ -2240,10 +2178,6 @@ Reaction_isSetCompartment (const Reaction_t *r)
 }
 
 
-/**
- * @return true (non-zero) if the reversible attribute of this Reaction is set,
- * false (0) otherwise.
- */
 LIBSBML_EXTERN
 int
 Reaction_isSetReversible (const Reaction_t *r)
@@ -2252,19 +2186,6 @@ Reaction_isSetReversible (const Reaction_t *r)
 }
 
 
-/**
- * Sets the id of this Reaction to a copy of sid.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with an id of NULL is equivalent to
- * unsetting the "id" attribute.
- */
 LIBSBML_EXTERN
 int
 Reaction_setId (Reaction_t *r, const char *sid)
@@ -2276,19 +2197,6 @@ Reaction_setId (Reaction_t *r, const char *sid)
 }
 
 
-/**
- * Sets the name of this Reaction to a copy of name.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with the name set to NULL is equivalent to
- * unsetting the "name" attribute.
- */
 LIBSBML_EXTERN
 int
 Reaction_setName (Reaction_t *r, const char *name)
@@ -2300,17 +2208,6 @@ Reaction_setName (Reaction_t *r, const char *name)
 }
 
 
-/**
- * Sets the KineticLaw of this Reaction to a copy of the given KineticLaw.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_LEVEL_MISMATCH
- * @li LIBSBML_VERSION_MISMATCH
- */
 LIBSBML_EXTERN
 int
 Reaction_setKineticLaw (Reaction_t *r, const KineticLaw_t *kl)
@@ -2322,15 +2219,6 @@ Reaction_setKineticLaw (Reaction_t *r, const KineticLaw_t *kl)
 }
 
 
-/**
- * Sets the reversible status of this Reaction to value (boolean).
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- */
 LIBSBML_EXTERN
 int
 Reaction_setReversible (Reaction_t *r, int value)
@@ -2342,15 +2230,6 @@ Reaction_setReversible (Reaction_t *r, int value)
 }
 
 
-/**
- * Sets the fast status of this Reaction to value (boolean).
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- */
 LIBSBML_EXTERN
 int
 Reaction_setFast (Reaction_t *r, int value)
@@ -2362,20 +2241,6 @@ Reaction_setFast (Reaction_t *r, int value)
 }
 
 
-/**
- * Sets the compartment of this Reaction to a copy of compartment.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_UNEXPECTED_ATTRIBUTE
- * @li LIBSBML_INVALID_ATTRIBUTE_VALUE
- *
- * @note Using this function with the compartment set to NULL is equivalent to
- * unsetting the "compartment" attribute.
- */
 LIBSBML_EXTERN
 int
 Reaction_setCompartment (Reaction_t *r, const char *compartment)
@@ -2388,16 +2253,6 @@ Reaction_setCompartment (Reaction_t *r, const char *compartment)
 }
 
 
-/**
- * Unsets the name of this Reaction.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 Reaction_unsetName (Reaction_t *r)
@@ -2409,17 +2264,6 @@ Reaction_unsetName (Reaction_t *r)
 }
 
 
-/**
- * Unsets the compartment of this Reaction.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_UNEXPECTED_ATTRIBUTE
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 Reaction_unsetCompartment (Reaction_t *r)
@@ -2431,16 +2275,6 @@ Reaction_unsetCompartment (Reaction_t *r)
 }
 
 
-/**
- * Unsets the KineticLaw of this Reaction.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 Reaction_unsetKineticLaw (Reaction_t *r)
@@ -2452,20 +2286,6 @@ Reaction_unsetKineticLaw (Reaction_t *r)
 }
 
 
-/**
- * Unsets the fast status of this Reation.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_OPERATION_FAILED
- *
- * In L1, fast is optional with a default of false, which means it is
- * effectively always set.  In L2, however, fast is optional with no
- * default value, so it may or may not be set to a specific value.
- */
 LIBSBML_EXTERN
 int
 Reaction_unsetFast (Reaction_t *r)
@@ -2477,21 +2297,17 @@ Reaction_unsetFast (Reaction_t *r)
 }
 
 
-/**
-  * Predicate returning @c true or @c false depending on whether
-  * all the required attributes for this Reaction object
-  * have been set.
-  *
- * @param r the Reaction_t structure to check.
- *
-  * @note The required attributes for a Reaction object are:
-  * @li id (name in L1)
-  * @li fast (in L3 only)
-  * @li reversible (in L3 only)
-  *
-  * @return a true if all the required
-  * attributes for this object have been defined, false otherwise.
-  */
+LIBSBML_EXTERN
+int
+Reaction_unsetReversible (Reaction_t *r)
+{
+  if (r != NULL)
+    return r->unsetReversible();
+  else
+    return LIBSBML_INVALID_OBJECT;
+}
+
+
 LIBSBML_EXTERN
 int
 Reaction_hasRequiredAttributes(Reaction_t *r)
@@ -2500,18 +2316,6 @@ Reaction_hasRequiredAttributes(Reaction_t *r)
 }
 
 
-/**
- * Adds a copy of the given reactant (SpeciesReference) to this Reaction.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_LEVEL_MISMATCH
- * @li LIBSBML_VERSION_MISMATCH
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 Reaction_addReactant (Reaction_t *r, const SpeciesReference_t *sr)
@@ -2523,18 +2327,6 @@ Reaction_addReactant (Reaction_t *r, const SpeciesReference_t *sr)
 }
 
 
-/**
- * Adds a copy of the given product (SpeciesReference) to this Reaction.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_LEVEL_MISMATCH
- * @li LIBSBML_VERSION_MISMATCH
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 Reaction_addProduct (Reaction_t *r, const SpeciesReference_t *sr)
@@ -2546,20 +2338,6 @@ Reaction_addProduct (Reaction_t *r, const SpeciesReference_t *sr)
 }
 
 
-/**
- * Adds a copy of the given modifier (ModifierSpeciesReference) to this
- * Reaction.
- *
- * @return integer value indicating success/failure of the
- * function.  @if clike The value is drawn from the
- * enumeration #OperationReturnValues_t. @endif@~ The possible values
- * returned by this function are:
- * @li LIBSBML_OPERATION_SUCCESS
- * @li LIBSBML_UNEXPECTED_ATTRIBUTE
- * @li LIBSBML_LEVEL_MISMATCH
- * @li LIBSBML_VERSION_MISMATCH
- * @li LIBSBML_OPERATION_FAILED
- */
 LIBSBML_EXTERN
 int
 Reaction_addModifier (Reaction_t *r, const SpeciesReference_t *msr)
@@ -2580,10 +2358,6 @@ Reaction_addModifier (Reaction_t *r, const SpeciesReference_t *msr)
 }
 
 
-/**
- * Creates a new SpeciesReference, adds it to this Reaction's list of
- * reactants and returns it.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_createReactant (Reaction_t *r)
@@ -2592,10 +2366,6 @@ Reaction_createReactant (Reaction_t *r)
 }
 
 
-/**
- * Creates a new SpeciesReference, adds it to this Reaction's list of
- * products and returns it.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_createProduct (Reaction_t *r)
@@ -2604,10 +2374,6 @@ Reaction_createProduct (Reaction_t *r)
 }
 
 
-/**
- * Creates a new SpeciesReference, adds it to this Reaction's list of
- * modifiers and returns it.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_createModifier (Reaction_t *r)
@@ -2616,10 +2382,6 @@ Reaction_createModifier (Reaction_t *r)
 }
 
 
-/**
- * Creates a new KineticLaw for this Reaction and returns it.  If this
- * Reaction had a previous KineticLaw, it will be destroyed.
- */
 LIBSBML_EXTERN
 KineticLaw_t *
 Reaction_createKineticLaw (Reaction_t *r)
@@ -2628,9 +2390,6 @@ Reaction_createKineticLaw (Reaction_t *r)
 }
 
 
-/**
- * @return the list of Reactants for this Reaction.
- */
 LIBSBML_EXTERN
 ListOf_t *
 Reaction_getListOfReactants (Reaction_t *r)
@@ -2639,9 +2398,6 @@ Reaction_getListOfReactants (Reaction_t *r)
 }
 
 
-/**
- * @return the list of Products for this Reaction.
- */
 LIBSBML_EXTERN
 ListOf_t *
 Reaction_getListOfProducts (Reaction_t *r)
@@ -2650,9 +2406,6 @@ Reaction_getListOfProducts (Reaction_t *r)
 }
 
 
-/**
- * @return the list of Modifiers for this Reaction.
- */
 LIBSBML_EXTERN
 ListOf_t *
 Reaction_getListOfModifiers (Reaction_t *r)
@@ -2661,9 +2414,6 @@ Reaction_getListOfModifiers (Reaction_t *r)
 }
 
 
-/**
- * @return the nth reactant (SpeciesReference) of this Reaction.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_getReactant (Reaction_t *r, unsigned int n)
@@ -2672,10 +2422,6 @@ Reaction_getReactant (Reaction_t *r, unsigned int n)
 }
 
 
-/**
- * @return the reactant (SpeciesReference) in this Reaction with the given
- * species or @c NULL if no such reactant exists.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_getReactantBySpecies (Reaction_t *r, const char *species)
@@ -2684,9 +2430,6 @@ Reaction_getReactantBySpecies (Reaction_t *r, const char *species)
 }
 
 
-/**
- * @return the nth product (SpeciesReference) of this Reaction.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_getProduct (Reaction_t *r, unsigned int n)
@@ -2695,10 +2438,6 @@ Reaction_getProduct (Reaction_t *r, unsigned int n)
 }
 
 
-/**
- * @return the product (SpeciesReference) in this Reaction with the given
- * species or @c NULL if no such product exists.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_getProductBySpecies (Reaction_t *r, const char *species)
@@ -2707,9 +2446,6 @@ Reaction_getProductBySpecies (Reaction_t *r, const char *species)
 }
 
 
-/**
- * @return the nth modifier (ModifierSpeciesReference) of this Reaction.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_getModifier (Reaction_t *r, unsigned int n)
@@ -2718,10 +2454,6 @@ Reaction_getModifier (Reaction_t *r, unsigned int n)
 }
 
 
-/**
- * @return the modifier (ModifierSpeciesReference) in this Reaction with
- * the given species or @c NULL if no such modifier exists.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_getModifierBySpecies (Reaction_t *r, const char *species)
@@ -2729,9 +2461,6 @@ Reaction_getModifierBySpecies (Reaction_t *r, const char *species)
   return (r != NULL &&  species != NULL) ? r->getModifier(species) : NULL;
 }
 
-/**
- * @return the number of reactants (SpeciesReferences) in this Reaction.
- */
 LIBSBML_EXTERN
 unsigned int
 Reaction_getNumReactants (const Reaction_t *r)
@@ -2740,9 +2469,6 @@ Reaction_getNumReactants (const Reaction_t *r)
 }
 
 
-/**
- * @return the number of products (SpeciesReferences) in this Reaction.
- */
 LIBSBML_EXTERN
 unsigned int
 Reaction_getNumProducts (const Reaction_t *r)
@@ -2751,10 +2477,6 @@ Reaction_getNumProducts (const Reaction_t *r)
 }
 
 
-/**
- * @return the number of modifiers (ModifierSpeciesReferences) in this
- * Reaction.
- */
 LIBSBML_EXTERN
 unsigned int
 Reaction_getNumModifiers (const Reaction_t *r)
@@ -2763,19 +2485,6 @@ Reaction_getNumModifiers (const Reaction_t *r)
 }
 
 
-/**
- * Removes the nth reactant SpeciesReference_t object from this 
- * Reaction_t object and returns a pointer to it.
- *
- * The caller owns the returned object and is responsible for deleting it.
- *
- * @param r the Reaction_t structure
- * @param n the integer index of the reactant SpeciesReference_t to remove
- *
- * @return the reactant SpeciesReference_t object removed.  As mentioned 
- * above, the caller owns the returned object. @c NULL is returned if the 
- * given index is out of range.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_removeReactant (Reaction_t *r, unsigned int n)
@@ -2784,22 +2493,6 @@ Reaction_removeReactant (Reaction_t *r, unsigned int n)
 }
 
 
-/**
- * Removes the reactant SpeciesReference_t object with the given 
- * "species" attribute from this Reaction_t object and returns a pointer
- * to it.
- *
- * The caller owns the returned object and is responsible for deleting it.
- *
- * @param r the Reaction_t structure
- * @param species the "species" attribute of the reactant SpeciesReference_t 
- * to remove
- *
- * @return the reactant SpeciesReference_t object removed.  As mentioned 
- * above, the caller owns the returned object. @c NULL is returned if no 
- * reactant SpeciesReference_t object with the "species" attribute exists 
- * in this Reaction.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_removeReactantBySpecies (Reaction_t *r, const char *species)
@@ -2811,19 +2504,6 @@ Reaction_removeReactantBySpecies (Reaction_t *r, const char *species)
 }
 
 
-/**
- * Removes the nth product SpeciesReference_t object from this 
- * Reaction_t object and returns a pointer to it.
- *
- * The caller owns the returned object and is responsible for deleting it.
- *
- * @param r the Reaction_t structure
- * @param n the integer index of the product SpeciesReference_t to remove
- *
- * @return the product SpeciesReference_t object removed.  As mentioned 
- * above, the caller owns the returned object. @c NULL is returned if the 
- * given index is out of range.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_removeProduct (Reaction_t *r, unsigned int n)
@@ -2832,22 +2512,6 @@ Reaction_removeProduct (Reaction_t *r, unsigned int n)
 }
 
 
-/**
- * Removes the product SpeciesReference_t object with the given 
- * "species" attribute from this Reaction_t object and returns a pointer
- * to it.
- *
- * The caller owns the returned object and is responsible for deleting it.
- *
- * @param r the Reaction_t structure
- * @param species the "species" attribute of the product SpeciesReference_t 
- * to remove
- *
- * @return the product SpeciesReference_t object removed.  As mentioned 
- * above, the caller owns the returned object. @c NULL is returned if no 
- * product SpeciesReference_t object with the "species" attribute exists 
- * in this Reaction.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_removeProductBySpecies (Reaction_t *r, const char *species)
@@ -2859,19 +2523,6 @@ Reaction_removeProductBySpecies (Reaction_t *r, const char *species)
 }
 
 
-/**
- * Removes the nth modifier SpeciesReference_t object from this 
- * Reaction_t object and returns a pointer to it.
- *
- * The caller owns the returned object and is responsible for deleting it.
- *
- * @param r the Reaction_t structure
- * @param n the integer index of the modifier SpeciesReference_t to remove
- *
- * @return the modifier SpeciesReference_t object removed.  As mentioned 
- * above, the caller owns the returned object. @c NULL is returned if the 
- * given index is out of range.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_removeModifier (Reaction_t *r, unsigned int n)
@@ -2880,22 +2531,6 @@ Reaction_removeModifier (Reaction_t *r, unsigned int n)
 }
 
 
-/**
- * Removes the modifier SpeciesReference_t object with the given 
- * "species" attribute from this Reaction_t object and returns a pointer
- * to it.
- *
- * The caller owns the returned object and is responsible for deleting it.
- *
- * @param r the Reaction_t structure
- * @param species the "species" attribute of the modifier SpeciesReference_t 
- * to remove
- *
- * @return the modifier SpeciesReference_t object removed.  As mentioned 
- * above, the caller owns the returned object. @c NULL is returned if no 
- * modifier SpeciesReference_t object with the "species" attribute exists 
- * in this Reaction.
- */
 LIBSBML_EXTERN
 SpeciesReference_t *
 Reaction_removeModifierBySpecies (Reaction_t *r, const char *species)
@@ -2907,10 +2542,6 @@ Reaction_removeModifierBySpecies (Reaction_t *r, const char *species)
 }
 
 
-/**
- * @return item in this ListOfReaction with the given @p id or @c NULL if no such
- * item exists.
- */
 LIBSBML_EXTERN
 Reaction_t *
 ListOfReactions_getById (ListOf_t *lo, const char *sid)
@@ -2923,11 +2554,6 @@ ListOfReactions_getById (ListOf_t *lo, const char *sid)
 }
 
 
-/**
- * Removes item in this ListOf items with the given @p id or @c NULL if no such
- * item exists.  The caller owns the returned item and is responsible for
- * deleting it.
- */
 LIBSBML_EXTERN
 Reaction_t *
 ListOfReactions_removeById (ListOf_t *lo, const char *sid)
