@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -226,20 +226,28 @@ Model::convertL3ToL1 (bool strict)
     if (r->isSetKineticLaw())
     {
       KineticLaw *kl = r->getKineticLaw();
-      for (unsigned int j = 0; j < kl->getNumLocalParameters(); j++)
+      unsigned int numLocals = kl->getNumLocalParameters();
+      for (unsigned int j = 0; j < numLocals; j++)
       {
         Parameter *lp = new Parameter(getLevel(), getVersion());
         (*lp) = *(kl->getLocalParameter(j));
+        // make parameter constant by default
+        lp->initDefaults();
         kl->addParameter(lp);
-        delete kl->removeLocalParameter(j);
         delete lp;
       }
+      for (unsigned int j = numLocals; j > 0; j--)
+      {
+        delete kl->removeLocalParameter(j-1);
+      }
     }
   }
+
+  dealWithDefaultValues();
 }
 
 
-/* convert from L1 to L3 */
+/* convert from L3 to L2 */
 void 
 Model::convertL3ToL2 (bool strict)
 {
@@ -252,22 +260,172 @@ Model::convertL3ToL2 (bool strict)
   for (unsigned int i = 0; i < getNumReactions(); i++)
   {
     Reaction *r = getReaction(i);
+
     if (r->isSetKineticLaw())
     {
       KineticLaw *kl = r->getKineticLaw();
-      for (unsigned int j = 0; j < kl->getNumLocalParameters(); j++)
+      unsigned int numLocals = kl->getNumLocalParameters();
+      for (unsigned int j = 0; j < numLocals; j++)
       {
         Parameter *lp = new Parameter(getLevel(), getVersion());
         (*lp) = *(kl->getLocalParameter(j));
+        // make parameter constant by default
+        lp->initDefaults();
         kl->addParameter(lp);
-        delete kl->removeLocalParameter(j);
         delete lp;
       }
+      for (unsigned int j = numLocals; j > 0; j--)
+      {
+        delete kl->removeLocalParameter(j-1);
+      }
     }
   }
+
+  dealWithDefaultValues();
 }
 
 
+void
+Model::dealWithDefaultValues()
+{
+  for (unsigned int i = 0; i < getNumCompartments(); i++)
+  {
+    // save any values that are assigned
+    Compartment *c = getCompartment(i);
+    bool constant = c->getConstant();
+    bool replaceConstant = (c->isSetConstant() == true && constant == false);
+    double spDims = c->getSpatialDimensionsAsDouble();
+    bool replaceSD = (c->isSetSpatialDimensions() == true &&
+      util_isEqual(spDims, 3.0) == false);
+
+    c->initDefaults();
+    if (replaceConstant) 
+      c->setConstant(constant);
+    if (replaceSD) 
+      c->setSpatialDimensions(spDims);
+  }
+
+  for (unsigned int i = 0; i < getNumUnitDefinitions(); i++)
+  {
+    UnitDefinition *ud = getUnitDefinition(i);
+    for (unsigned int j = 0; j < ud->getNumUnits(); j++)
+    {
+      // save any values that are assigned
+      Unit *u = ud->getUnit(j);
+      double exp = u->getExponentAsDouble();
+      bool replaceExp = (u->isSetExponent() == true &&
+        util_isEqual(exp, 1.0) == false);
+      unsigned int scale = u->getScale();
+      bool replaceScale = (u->isSetScale() == true && scale != 0);
+      double mult = u->getMultiplier();
+      bool replaceMult = (u->isSetMultiplier() == true &&
+        util_isEqual(mult, 1.0) == false);
+
+      u->initDefaults();
+      if (replaceExp) 
+        u->setExponent(exp);
+      if (replaceScale) 
+        u->setScale(scale);
+      if (replaceMult) 
+        u->setMultiplier(mult);
+    }
+  }
+
+  for (unsigned int i = 0; i < getNumSpecies(); i++)
+  {
+    // save any values that are assigned
+    Species *s = getSpecies(i);
+    bool constant = s->getConstant();
+    bool replaceConstant = (s->isSetConstant() == true && constant == true);
+    bool hosu = s->getHasOnlySubstanceUnits();
+    bool replaceHOSU = (s->isSetHasOnlySubstanceUnits() == true 
+      && hosu == true);
+    bool bc = s->getBoundaryCondition();
+    bool replaceBc = (s->isSetBoundaryCondition() == true && bc == true);
+
+    s->initDefaults();
+    if (replaceConstant) 
+      s->setConstant(constant);
+    if (replaceHOSU) 
+      s->setHasOnlySubstanceUnits(hosu);
+    if (replaceBc)
+      s->setBoundaryCondition(bc);
+  }
+
+  for (unsigned int i = 0; i < getNumParameters(); i++)
+  {
+    // save any values that are assigned
+    Parameter *p = getParameter(i);
+    bool constant = p->getConstant();
+    bool replaceConstant = (p->isSetConstant() == true && constant == false);
+
+    p->initDefaults();
+    if (replaceConstant) 
+      p->setConstant(constant);
+  }
+
+  for (unsigned int i = 0; i < getNumReactions(); i++)
+  {
+    Reaction *r = getReaction(i);
+
+    // check we reset default values if necessary
+    bool rev = r->getReversible();
+    bool replaceRev = (r->isSetReversible() == true 
+      && r->getReversible() == false);
+    r->initDefaults();
+    if (replaceRev == true)
+      r->setReversible(rev);
+
+    for (unsigned int j = 0; j < r->getNumReactants(); j++)
+    {
+      SpeciesReference *sr = r->getReactant(j);
+
+      // now we may have already created a stoichiometry math element
+      // in which case we do not want to mess with the speciesReference
+      if (sr->isSetStoichiometryMath() == false)
+      {
+        double stoich = sr->getStoichiometry();
+        bool replaceStoich = (sr->isSetStoichiometry() == true && 
+          util_isEqual(stoich, 1.0) == 0);
+
+        sr->initDefaults();
+        if (replaceStoich)
+          sr->setStoichiometry(stoich);
+      }
+    }
+    for (unsigned int j = 0; j < r->getNumProducts(); j++)
+    {
+      SpeciesReference *sr = r->getProduct(j);
+
+      // now we may have already created a stoichiometry math element
+      // in which case we do not want to mess with the speciesReference
+      if (sr->isSetStoichiometryMath() == false)
+      {
+        double stoich = sr->getStoichiometry();
+        bool replaceStoich = (sr->isSetStoichiometry() == true && 
+          util_isEqual(stoich, 1.0) == 0);
+
+        sr->initDefaults();
+        if (replaceStoich)
+          sr->setStoichiometry(stoich);
+      }
+    }
+  }
+
+  for (unsigned int i = 0; i < getNumEvents(); i++)
+  {
+    Event * e = getEvent(i);
+    bool uvftt = e->getUseValuesFromTriggerTime();
+    bool replaceUvftt = (e->isSetUseValuesFromTriggerTime() == true 
+      && uvftt == false);
+    e->initDefaults();
+    if (replaceUvftt == true)
+      e->setUseValuesFromTriggerTime(uvftt);
+
+  }
+
+}
+
 void
 Model::removeCompartmentTypes()
 {
@@ -1222,6 +1380,16 @@ Model::dealWithEvents(bool strict)
   }
 }
 
+bool isValidUnit(const Model* model, const std::string& unitId)
+{
+  if (model == NULL) return false;
+
+  if (model->getUnitDefinition(unitId) != NULL)
+    return true;
+
+  return UnitKind_forName(unitId.c_str()) != UNIT_KIND_INVALID;
+}
+
 void
 Model::dealWithModelUnits(bool strict)
 {
@@ -1230,7 +1398,7 @@ Model::dealWithModelUnits(bool strict)
   unsigned int n = 0;
   unsigned int num = elements->getSize();
   
-  if (isSetVolumeUnits())
+  if (isSetVolumeUnits() && isValidUnit(this, getVolumeUnits()))
   {
     std::string volume = getVolumeUnits();
     // if in an L3 model a user used volume as an id of a UnitDefinition
@@ -1273,7 +1441,7 @@ Model::dealWithModelUnits(bool strict)
     delete ud;
     if (strict) unsetVolumeUnits();
   }
-  if (isSetAreaUnits())
+  if (isSetAreaUnits() && isValidUnit(this, getAreaUnits()))
   {
     std::string area = getAreaUnits();
     // if in an L3 model a user used area as an id of a UnitDefinition
@@ -1316,7 +1484,7 @@ Model::dealWithModelUnits(bool strict)
     delete ud;
     if (strict) unsetAreaUnits();
   }
-  if (isSetLengthUnits())
+  if (isSetLengthUnits() && isValidUnit(this, getLengthUnits()))
   {
     std::string length = getLengthUnits();
     // if in an L3 model a user used length as an id of a UnitDefinition
@@ -1359,7 +1527,7 @@ Model::dealWithModelUnits(bool strict)
     delete ud;
     if (strict) unsetLengthUnits();
   }
-  if (isSetSubstanceUnits())
+  if (isSetSubstanceUnits() && isValidUnit(this, getSubstanceUnits()))
   {
     std::string substance = getSubstanceUnits();
     // if in an L3 model a user used substance as an id of a UnitDefinition
@@ -1402,7 +1570,7 @@ Model::dealWithModelUnits(bool strict)
     delete ud;
     if (strict) unsetSubstanceUnits();
   }
-  if (isSetTimeUnits())
+  if (isSetTimeUnits() && isValidUnit(this, getTimeUnits()))
   {
     std::string time = getTimeUnits();
     // if in an L3 model a user used time as an id of a UnitDefinition
