@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -123,7 +123,7 @@ public:
    *
    * @return the (deep) copy of this SBasePlugin object.
    */
-  virtual SBasePlugin* clone () const = 0;
+  virtual SBasePlugin* clone () const;
 
 
   /**
@@ -663,6 +663,22 @@ public:
   /** @endcond */
 
 
+  virtual bool isValidTypeForList(SBase* item) const;
+
+    /** @cond doxygenLibsbmlInternal */
+
+  /**
+   * Accepts the given SBMLVisitor.
+   *
+   * @return the result of calling <code>v.visit()</code>, which indicates
+   * whether or not the Visitor would like to visit the SBML object's next
+   * sibling object (if available).
+   */
+  virtual bool accept (SBMLVisitor& v) const;
+
+  /** @endcond */
+
+
 protected:
   /** @cond doxygenLibsbmlInternal */
   /**
