@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -244,6 +244,13 @@ public:
  
   virtual bool hasCorrectNumberArguments() const;
  
+  virtual ASTBasePlugin* getPlugin(const std::string& package);
+  virtual const ASTBasePlugin* getPlugin(const std::string& package) const;
+  virtual ASTBasePlugin* getPlugin(unsigned int n);
+  virtual const ASTBasePlugin* getPlugin(unsigned int n) const;
+
+  ASTBase* getMember() const;
+
   /************************************* 
    * read/write functions 
    */
