@@ -7,12 +7,12 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
  *
- * Copyright (C) 2009-2012 jointly by the following organizations: 
+ * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
@@ -185,7 +185,7 @@ ASTNode::ASTNode (ASTNodeType_t type) :
 
   for (unsigned int i = 0; i < getNumPlugins(); i++)
   {
-    getPlugin(i)->connectToParent(this);
+    ASTBase::getPlugin(i)->connectToParent(this);
   }
 }
   
@@ -285,7 +285,7 @@ ASTNode::ASTNode (int type) :
 
   for (unsigned int i = 0; i < getNumPlugins(); i++)
   {
-    getPlugin(i)->connectToParent(this);
+    ASTBase::getPlugin(i)->connectToParent(this);
   }
 }
 /** @endcond */  
@@ -407,7 +407,7 @@ ASTBase()
 
   for (unsigned int i = 0; i < getNumPlugins(); i++)
   {
-    getPlugin(i)->connectToParent(this);
+    ASTBase::getPlugin(i)->connectToParent(this);
   }
 }
 /** @endcond */
@@ -869,9 +869,23 @@ ASTNode::getReal () const
 {
   /* HACK TO REPLICATE OLD AST */
   // hack since old ASTNode would reset the "real" value of an integer to 0
-  if (mNumber != NULL && mNumber->getType() != AST_INTEGER)
+  if (mNumber != NULL)
   {
-    return mNumber->getValue();
+    switch (mNumber->getType())
+    {
+    case AST_INTEGER:
+    case AST_NAME:
+    case AST_NAME_TIME:
+    case AST_CONSTANT_E:
+    case AST_CONSTANT_PI:
+    case AST_CONSTANT_TRUE:
+    case AST_CONSTANT_FALSE:
+      return 0;
+      break;
+    default:
+      return mNumber->getValue();
+      break;
+    }
   }
   else
   {
@@ -933,6 +947,23 @@ ASTNode::getExtendedType () const
   }
 }
 
+double
+ASTNode::getValue() const
+{
+  if (mNumber != NULL)
+  {
+    return mNumber->getValue();
+  }
+  else if (mFunction != NULL)
+  {
+    return mFunction->getValue();
+  }
+  else
+  {
+    return ASTBase::getValue();
+  }
+}
+
 
 /** @cond doxygenLibsbmlInternal */
 const std::string&
@@ -1322,7 +1353,7 @@ ASTNode::setType (int type)
 
   for (unsigned int i = 0; i < getNumPlugins(); i++)
   {
-    getPlugin(i)->connectToParent(this);
+    ASTBase::getPlugin(i)->connectToParent(this);
   }
 
   if (copyNumber != NULL)
@@ -2684,7 +2715,7 @@ ASTNode::write(XMLOutputStream& stream) const
 
     for (unsigned int i = 0; i < getNumPlugins(); i++)
     {
-      getPlugin(i)->writeXMLNS(stream);
+      ASTBase::getPlugin(i)->writeXMLNS(stream);
     }
   }
 
@@ -3331,6 +3362,57 @@ ASTNode::unsetUserData()
   return success;
 }
   
+/** @cond doxygenLibsbmlInternal */
+
+ASTBasePlugin* 
+ASTNode::getPlugin(const std::string& package)
+{
+  if (mNumber != NULL)
+  {
+    return mNumber->getPlugin(package);
+  }
+  else if (mFunction != NULL)
+  {
+    return mFunction->getPlugin(package);
+  }
+  else
+  {
+    return ASTBase::getPlugin(package);
+  }
+}
+
+const ASTBasePlugin*
+ASTNode::getPlugin(const std::string& package) const
+{
+  return const_cast<ASTNode*>(this)->getPlugin(package);
+}
+
+
+ASTBasePlugin*
+ASTNode::getPlugin(unsigned int n)
+{
+  if (mNumber != NULL)
+  {
+    return mNumber->getPlugin(n);
+  }
+  else if (mFunction != NULL)
+  {
+    return mFunction->getPlugin(n);
+  }
+  else
+  {
+    return ASTBase::getPlugin(n);
+  }
+}
+
+
+const ASTBasePlugin*
+  ASTNode::getPlugin(unsigned int n) const
+{
+  return const_cast<ASTNode*>(this)->getPlugin(n);
+}
+
+/** @endcond */
 
 bool
 ASTNode::canonicalize ()
@@ -3623,7 +3705,7 @@ ASTNode::connectPlugins()
 {
   for (unsigned int i = 0; i < getNumPlugins(); i++)
   {
-    getPlugin(i)->connectToParent(this);
+    ASTBase::getPlugin(i)->connectToParent(this);
   }
 }
 /** @endcond */
@@ -3848,6 +3930,15 @@ ASTNode_getExponent (const ASTNode_t *node)
 }
 
 
+LIBSBML_EXTERN
+double
+ASTNode_getValue (const ASTNode_t *node)
+{
+  if (node == NULL) return util_NaN();
+  return static_cast<const ASTNode*>(node)->getValue();
+}
+
+
 LIBSBML_EXTERN
 int
 ASTNode_getPrecedence (const ASTNode_t *node)
@@ -4458,7 +4549,7 @@ ASTNode_setUserData(ASTNode_t* node, void *userData)
 
 LIBSBML_EXTERN
 void *
-ASTNode_getUserData(ASTNode_t* node)
+ASTNode_getUserData(const ASTNode_t* node)
 {
   if (node == NULL) return NULL;
   return node->getUserData();
@@ -4476,7 +4567,7 @@ ASTNode_unsetUserData(ASTNode_t* node)
 
 LIBSBML_EXTERN
 int
-ASTNode_isSetUserData(ASTNode_t* node)
+ASTNode_isSetUserData(const ASTNode_t* node)
 {
   if (node == NULL) return (int) false;
   return static_cast<int>(node->isSetUserData());
