@@ -8,7 +8,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -37,7 +37,7 @@
 
 #ifdef __cplusplus
 
-//using namespace std;
+using namespace std;
 
 LIBSBML_CPP_NAMESPACE_BEGIN
 
@@ -116,6 +116,14 @@ CompSBasePlugin::createObject(XMLInputStream& stream)
 
   const std::string& targetPrefix = (xmlns.hasURI(mURI)) ? xmlns.getPrefix(mURI) : mPrefix;
   
+  const SBase* parent = getParentSBMLObject();
+  string message = "";
+  if (parent) {
+    message = "The <" + parent->getElementName() + "> ";
+    if (parent->isSetId()) { //LS DEBUG
+      message += "with the id '" + parent->getId() + "' ";
+    }
+  }
   if (prefix == targetPrefix)
   {
     if ( name == "listOfReplacedElements" ) 
@@ -123,7 +131,7 @@ CompSBasePlugin::createObject(XMLInputStream& stream)
       if (mListOfReplacedElements != NULL)
       {
         getErrorLog()->logPackageError("comp", CompOneListOfReplacedElements, 
-          getPackageVersion(), getLevel(), getVersion());
+          getPackageVersion(), getLevel(), getVersion(), message + "may only have one <listOfReplacedElements>");
       }
       createListOfReplacedElements();
       object = mListOfReplacedElements;
@@ -148,7 +156,7 @@ CompSBasePlugin::createObject(XMLInputStream& stream)
         if (mSBML != NULL && getErrorLog() != NULL)
         {
           getErrorLog()->logPackageError("comp", CompOneReplacedByElement, 
-                          getPackageVersion(), getLevel(), getVersion());
+                          getPackageVersion(), getLevel(), getVersion(), message + "may only have one <replacedBy> child.");
         }
       }
       delete mReplacedBy;
