@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -52,7 +52,7 @@ Port::Port (unsigned int level, unsigned int version, unsigned int pkgVersion)
 
 
 Port::Port(CompPkgNamespaces* compns)
-  : SBaseRef(compns)
+  : SBaseRef(compns, true)
   , mId("")
   , mName("")
 {
@@ -268,7 +268,13 @@ Port::readAttributes (const XMLAttributes& attributes,
         logEmptyString("name", "<Port>");
       }
     }
-    //LS DEBUG:  add an error if the 'port' attribute was used.
+
+    if (isSetPortRef() == true)
+    {
+      getErrorLog()->logPackageError("comp", CompPortAllowedAttributes,
+        getPackageVersion(), sbmlLevel, sbmlVersion);
+      unsetPortRef();
+    }
   }
 }
 /** @endcond */
