@@ -7,8 +7,15 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright 2011 California Institute of Technology.
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
  * 
+ * Copyright 2011-2012 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -362,8 +369,18 @@ int ReplacedElement::performReplacementAndCollect(set<SBase*>* removed, set<SBas
     //Already deleted: can't get the deleted element's ID to 
     if (doc) {
       string error = "Cannot carry out replacement in ReplacedElement::performReplacement: a <" + parent->getElementName() + ">";
-      if (parent->isSetId()) {
-        error += " with the ID '" + parent->getId() + "'";
+      switch(parent->getTypeCode()) {
+      case SBML_INITIAL_ASSIGNMENT:
+      case SBML_EVENT_ASSIGNMENT:
+      case SBML_ASSIGNMENT_RULE:
+      case SBML_RATE_RULE:
+        //LS DEBUG:  could use other attribute values, or 'isSetActualId'.
+        break;
+      default:
+        if (parent->isSetId()) {
+          error += "with id '" + parent->getId() + "' ";
+        }
+        break;
       }
       error += " has a child <replacedElement> that points to something that has already been deleted, probably because its parent was deleted.";
       doc->getErrorLog()->logPackageError("comp", CompDeletedReplacement, getPackageVersion(), getLevel(), getVersion(), error, getLine(), getColumn());
@@ -378,8 +395,15 @@ int ReplacedElement::performReplacementAndCollect(set<SBase*>* removed, set<SBas
 
   //Perform any conversions on references in the submodel.
   ASTNode* blank = NULL;
-  ret = performConversions(parent, blank);
-  if (ret != LIBSBML_OPERATION_SUCCESS) return ret;
+  ret = performConversions(parent, &blank);
+  if (ret != LIBSBML_OPERATION_SUCCESS) 
+  {
+    if (blank != NULL)
+    {
+      delete blank;
+    }
+    return ret;
+  }
 
   CompSBasePlugin* refplug = static_cast<CompSBasePlugin*>(ref->getPlugin(getPrefix()));
   if (refplug != NULL) {
@@ -402,6 +426,12 @@ int ReplacedElement::performReplacementAndCollect(set<SBase*>* removed, set<SBas
   if (toremove) {
     toremove->insert(ref);
   }
+
+  if (blank != NULL)
+  {
+    delete blank;
+  }
+
   return LIBSBML_OPERATION_SUCCESS;
 }
 
@@ -467,11 +497,8 @@ ReplacedElement::accept (SBMLVisitor& v) const
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- * 
- */
 LIBSBML_EXTERN
 ReplacedElement_t *
 ReplacedElement_create(unsigned int level, unsigned int version,
@@ -481,9 +508,6 @@ ReplacedElement_create(unsigned int level, unsigned int version,
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 void
 ReplacedElement_free(ReplacedElement_t * re)
@@ -493,9 +517,6 @@ ReplacedElement_free(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 ReplacedElement_t *
 ReplacedElement_clone(ReplacedElement_t * re)
@@ -511,9 +532,6 @@ ReplacedElement_clone(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 ReplacedElement_getSubmodelRef(ReplacedElement_t * re)
@@ -525,9 +543,6 @@ ReplacedElement_getSubmodelRef(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 ReplacedElement_getDeletion(ReplacedElement_t * re)
@@ -539,9 +554,6 @@ ReplacedElement_getDeletion(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 char *
 ReplacedElement_getConversionFactor(ReplacedElement_t * re)
@@ -553,9 +565,6 @@ ReplacedElement_getConversionFactor(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 ReplacedElement_isSetSubmodelRef(ReplacedElement_t * re)
@@ -564,9 +573,6 @@ ReplacedElement_isSetSubmodelRef(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 ReplacedElement_isSetDeletion(ReplacedElement_t * re)
@@ -575,9 +581,6 @@ ReplacedElement_isSetDeletion(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 ReplacedElement_isSetConversionFactor(ReplacedElement_t * re)
@@ -586,9 +589,6 @@ ReplacedElement_isSetConversionFactor(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 ReplacedElement_setSubmodelRef(ReplacedElement_t * re, const char * submodelRef)
@@ -597,9 +597,6 @@ ReplacedElement_setSubmodelRef(ReplacedElement_t * re, const char * submodelRef)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 ReplacedElement_setDeletion(ReplacedElement_t * re, const char * deletion)
@@ -608,9 +605,6 @@ ReplacedElement_setDeletion(ReplacedElement_t * re, const char * deletion)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 ReplacedElement_setConversionFactor(ReplacedElement_t * re, const char * conversionFactor)
@@ -619,9 +613,6 @@ ReplacedElement_setConversionFactor(ReplacedElement_t * re, const char * convers
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 ReplacedElement_unsetSubmodelRef(ReplacedElement_t * re)
@@ -630,9 +621,6 @@ ReplacedElement_unsetSubmodelRef(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 ReplacedElement_unsetDeletion(ReplacedElement_t * re)
@@ -641,9 +629,6 @@ ReplacedElement_unsetDeletion(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 ReplacedElement_unsetConversionFactor(ReplacedElement_t * re)
@@ -652,9 +637,6 @@ ReplacedElement_unsetConversionFactor(ReplacedElement_t * re)
 }
 
 
-/**
- * 
- */
 LIBSBML_EXTERN
 int
 ReplacedElement_hasRequiredAttributes(ReplacedElement_t * re)
