@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -77,7 +77,7 @@ protected:
   /** @cond doxygenLibsbmlInternal */
   AssociationTypeCode_t mType;
   std::string mReference;
-  std::vector<Association> mAssociations;
+  std::vector<Association*> mAssociations;
   /** @endcond */
 
 public:
@@ -416,7 +416,6 @@ protected:
                                const ExpectedAttributes& expectedAttributes);
   /** @endcond */
 
-
   /** @cond doxygenLibsbmlInternal */
   /**
    * Subclasses should override this method to write their XML attributes
