@@ -6,9 +6,16 @@
  *<!---------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
- *
- * Copyright 2009-2013 California Institute of Technology.
  * 
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
+ * Copyright (C) 2009-2013 jointly by the following organizations: 
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -374,7 +381,7 @@ FluxBound::setValue (const double value)
 /*
  * @return the value of this SBML object.
  */
-const double
+double
 FluxBound::getValue () const
 {
   return mValue;
@@ -870,6 +877,7 @@ ListOfFluxBounds::createObject (XMLInputStream& stream)
       FBC_CREATE_NS(fbcns, getSBMLNamespaces());
       object = new FluxBound(fbcns);
       appendAndOwn(object);
+      delete fbcns;
       //mItems.push_back(object);
     } 
     catch(...)
@@ -898,7 +906,8 @@ ListOfFluxBounds::writeXMLNS (XMLOutputStream& stream) const
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(FbcExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(FbcExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(FbcExtension::getXmlnsL3V1V1(),prefix);
     }
@@ -911,11 +920,8 @@ ListOfFluxBounds::writeXMLNS (XMLOutputStream& stream) const
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
-/**
- *
- */
 LIBSBML_EXTERN
 FluxBound_t *
 FluxBound_create(unsigned int level, unsigned int version, unsigned int pkgversion)
@@ -924,9 +930,6 @@ FluxBound_create(unsigned int level, unsigned int version, unsigned int pkgversi
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 const char *
 FluxBound_getId(FluxBound_t * fb)
@@ -938,9 +941,6 @@ FluxBound_getId(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_isSetId(FluxBound_t * fb)
@@ -949,9 +949,6 @@ FluxBound_isSetId(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_setId(FluxBound_t * fb, const char * id)
@@ -960,9 +957,6 @@ FluxBound_setId(FluxBound_t * fb, const char * id)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_unsetId(FluxBound_t * fb)
@@ -970,9 +964,6 @@ FluxBound_unsetId(FluxBound_t * fb)
   return (fb != NULL) ? fb->unsetId() : LIBSBML_INVALID_OBJECT;
 }
 
-/**
- *
- */
 LIBSBML_EXTERN
 const char *
 FluxBound_getName(FluxBound_t * fb)
@@ -982,9 +973,6 @@ FluxBound_getName(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_isSetName(FluxBound_t * fb)
@@ -994,9 +982,6 @@ FluxBound_isSetName(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_setName(FluxBound_t * fb, const char * name)
@@ -1006,9 +991,6 @@ FluxBound_setName(FluxBound_t * fb, const char * name)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_unsetName(FluxBound_t * fb)
@@ -1018,9 +1000,6 @@ FluxBound_unsetName(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 const char *
 FluxBound_getReaction(FluxBound_t * fb)
@@ -1032,9 +1011,6 @@ FluxBound_getReaction(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_isSetReaction(FluxBound_t * fb)
@@ -1043,9 +1019,6 @@ FluxBound_isSetReaction(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_setReaction(FluxBound_t * fb, const char * reaction)
@@ -1054,9 +1027,6 @@ FluxBound_setReaction(FluxBound_t * fb, const char * reaction)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_unsetReaction(FluxBound_t * fb)
@@ -1065,9 +1035,6 @@ FluxBound_unsetReaction(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 const char *
 FluxBound_getOperation(FluxBound_t * fb)
@@ -1079,9 +1046,6 @@ FluxBound_getOperation(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_isSetOperation(FluxBound_t * fb)
@@ -1090,9 +1054,6 @@ FluxBound_isSetOperation(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_setOperation(FluxBound_t * fb, const char * operation)
@@ -1101,9 +1062,6 @@ FluxBound_setOperation(FluxBound_t * fb, const char * operation)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_unsetOperation(FluxBound_t * fb)
@@ -1112,9 +1070,6 @@ FluxBound_unsetOperation(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 double
 FluxBound_getValue(FluxBound_t * fb)
@@ -1123,9 +1078,6 @@ FluxBound_getValue(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_isSetValue(FluxBound_t * fb)
@@ -1134,9 +1086,6 @@ FluxBound_isSetValue(FluxBound_t * fb)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_setValue(FluxBound_t * fb, double value)
@@ -1145,9 +1094,6 @@ FluxBound_setValue(FluxBound_t * fb, double value)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int
 FluxBound_unsetValue(FluxBound_t * fb)
@@ -1168,9 +1114,6 @@ const char* FLUXBOUND_OPERATION_STRINGS[] =
 };
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 const char* 
 FluxBoundOperation_toString(FluxBoundOperation_t type)
@@ -1191,9 +1134,6 @@ FluxBoundOperation_toString(FluxBoundOperation_t type)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 FluxBoundOperation_t 
 FluxBoundOperation_fromString(const char* s)
@@ -1220,9 +1160,6 @@ FluxBoundOperation_fromString(const char* s)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int 
 FluxBoundOperation_isValidFluxBoundOperation(FluxBoundOperation_t effect)
@@ -1240,9 +1177,6 @@ FluxBoundOperation_isValidFluxBoundOperation(FluxBoundOperation_t effect)
 }
 
 
-/**
- *
- */
 LIBSBML_EXTERN
 int 
 FluxBoundOperation_isValidFluxBoundOperationString(const char* s)
