@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  * 
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -89,6 +89,7 @@ ConversionProperties
 {
   static ConversionProperties prop;
   prop.addOption("convert fbc to cobra", true, "convert FBC L3V1 to SBML L2V4 with COBRA annotation");
+  prop.addOption("overwriteReactionNotes", false, "write gene association into reaction notes, even if the reaction has notes already");
   return prop;
 }
 
@@ -142,7 +143,9 @@ void createKineticLawForReaction(Reaction* reaction)
     fluxValue->setId("FLUX_VALUE");
     fluxValue->setValue(0);
     fluxValue->setUnits("dimensionless");
-    law->setMath(SBML_parseFormula("FLUX_VALUE"));
+    ASTNode* astn = SBML_parseFormula("FLUX_VALUE");
+    law->setMath(astn);
+    delete astn;
   }
 
   LocalParameter* LB = law->getLocalParameter("LOWER_BOUND");
@@ -210,6 +213,21 @@ string getNotesForFormula(const string& formula)
   return str.str();
 }
 
+const GeneAssociation* getGeneAssociationForReaction(const FbcModelPlugin* plugin, const std::string& id)
+{
+  if (plugin == NULL) return NULL;
+
+  for (int i = 0; i < plugin->getNumGeneAssociations(); ++i)
+  {
+    const GeneAssociation* association = plugin->getGeneAssociation(i);
+    if (association == NULL) continue;
+
+    if (association->isSetReaction() && association->getReaction() == id)
+      return association;
+  }
+  return NULL;
+}
+
 int 
   FbcToCobraConverter::convert()
 {  
@@ -258,6 +276,12 @@ int
     }
   }
 
+
+  // overwrite reactionNotes
+  bool overwriteReactionNotes = getProperties() != NULL && 
+    getProperties()->hasOption("overwriteReactionNotes") &&
+    getProperties()->getBoolValue("overwriteReactionNotes");
+
   // create KineticLaw
   for (unsigned int i = 0; i < model->getNumReactions(); ++i)
   {
@@ -267,6 +291,25 @@ int
 
     createKineticLawForReaction(reaction);
 
+    // get gene association for reaction 
+    const GeneAssociation* association = getGeneAssociationForReaction(plugin, reaction->getId());
+    
+    if (association == NULL || association->getAssociation() == NULL) continue;
+
+    //unset notes if requested
+    if (reaction->isSetNotes() && overwriteReactionNotes)
+      reaction->unsetNotes();
+
+    // skip adding gene association if we already have notes
+    if (reaction->isSetNotes()) continue;
+
+    // write new notes 
+    reaction->setNotes(
+      "<body xmlns='http://www.w3.org/1999/xhtml'>\n"
+      "  <p>GENE_ASSOCIATION : " + association->getAssociation()->toInfix() +"</p>\n"
+      "</body>"
+    );
+
   }
 
   // update kinetic law from bounds
@@ -291,7 +334,8 @@ int
   // convert model to L2V1 (as L2V2 is the last model that had charge)
   mDocument->setConversionValidators(AllChecksON & UnitsCheckOFF);
   
-  ConversionProperties prop(new SBMLNamespaces(2,1));
+  SBMLNamespaces sbmlns21(2,1);
+  ConversionProperties prop(&sbmlns21);
   prop.addOption("strict", false, "should validity be preserved");
   prop.addOption("ignorePackages", true, "convert even if packages are used");
   prop.addOption("setLevelAndVersion", true, "convert the document to the given level and version");
