@@ -6,18 +6,16 @@
  * <!--------------------------------------------------------------------------
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
- *
+ * 
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
- *  
- * Copyright (C) 2006-2008 by the California Institute of Technology,
- *     Pasadena, CA, USA 
- *  
- * Copyright (C) 2002-2005 jointly by the following organizations: 
- *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. Japan Science and Technology Agency, Japan
- * 
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *
  * This library is free software; you can redistribute it and/or modify it
  * under the terms of the GNU Lesser General Public License as published by
  * the Free Software Foundation.  A copy of the license agreement is provided
@@ -83,11 +81,11 @@ static const packageErrorTableEntry fbcErrorTable[] =
     LIBSBML_CAT_IDENTIFIER_CONSISTENCY, 
     LIBSBML_SEV_ERROR,
     "(Extends validation rule #10301 in the SBML Level 3 Version 1 Core "
-    "specification.) Within a <model> object"
+    "specification.) Within a <model> object "
     "the values of the attributes id and fbc:id on every instance of the "
     "following classes of objects must be unique across the set of all id "
     "and fbc:id attribute values of all such objects in a model: the "
-    "model itself, plus all contained <functionDefinition>, <compartment>,"
+    "model itself, plus all contained <functionDefinition>, <compartment>, "
     "<species>, <reaction>, <speciesReference>, <modifierSpeciesReference>, "
     "<event>, and <parameter> objects, plus the <fluxBound>, <objective> "
     "and <fluxObjective> "
@@ -196,7 +194,7 @@ static const packageErrorTableEntry fbcErrorTable[] =
     LIBSBML_CAT_GENERAL_CONSISTENCY, 
     LIBSBML_SEV_ERROR,
     "A <listOfFluxBounds> object may have the optional attributes 'metaid' "
-    "and 'sboTerm' defined by SBML Level~3 Core. No other attributes from "
+    "and 'sboTerm' defined by SBML Level 3 Core. No other attributes from "
     "the SBML Level 3 Core namespace or the Flux Balance Constraints "
     "namespace are permitted on a <listOfFluxBounds> object. ",
     { "L3V1 Fbc V1 Section 3.3"
@@ -209,7 +207,7 @@ static const packageErrorTableEntry fbcErrorTable[] =
     LIBSBML_CAT_GENERAL_CONSISTENCY, 
     LIBSBML_SEV_ERROR,
     "A <listOfFluxBounds> object may have the optional attributes 'metaid' "
-    "and 'sboTerm' defined by SBML Level~3 Core. Additionally the "
+    "and 'sboTerm' defined by SBML Level 3 Core. Additionally the "
     "<listOfObjectives> must contain the attribute 'activeObjective'. "
     "No other attributes from the SBML Level 3 Core namespace or the Flux "
     "Balance Constraints namespace are permitted on a "
@@ -283,7 +281,7 @@ static const packageErrorTableEntry fbcErrorTable[] =
     "A <fluxBound> object may have the optional SBML Level 3 Core "
     "attributes 'metaid' and 'sboTerm'. No other attributes from the "
     "SBML Level 3 Core namespace are permitted on a <fluxBound>.",
-    { "L3V1 Core, Section 3.2."
+    { "L3V1 Core, Section 3.2"
     }
   },
   
@@ -295,7 +293,7 @@ static const packageErrorTableEntry fbcErrorTable[] =
     "A <fluxBound> object may have the optional SBML Level 3 Core "
     "subobjects for notes and annotations. No other elements from the "
     "SBML Level 3 Core namespace are permitted on a <fluxBound>.",
-    { "L3V1 Core, Section 3.2."
+    { "L3V1 Core, Section 3.2"
     }
   },
   
@@ -387,9 +385,9 @@ static const packageErrorTableEntry fbcErrorTable[] =
     "<objective> may only have 'metaId' and 'sboTerm' from L3 namespace",
     LIBSBML_CAT_GENERAL_CONSISTENCY, 
     LIBSBML_SEV_ERROR,
-    "A <objective> object may have the optional SBML Level 3 Core "
+    "An <objective> object may have the optional SBML Level 3 Core "
     "attributes 'metaid' and 'sboTerm'. No other attributes from the SBML "
-    "Level 3 Core namespace are permitted on a <objective>. ",
+    "Level 3 Core namespace are permitted on an <objective>. ",
     { "L3V1 Core, Section 3.2"
     }
   },
@@ -399,9 +397,9 @@ static const packageErrorTableEntry fbcErrorTable[] =
     "<objective> may only have <notes> and <annotations> from L3 Core",
     LIBSBML_CAT_GENERAL_CONSISTENCY, 
     LIBSBML_SEV_ERROR,
-    "A <objective> object may have the optional SBML Level 3 Core subobjects "
+    "An <objective> object may have the optional SBML Level 3 Core subobjects "
     "for notes and annotations. No other elements from the SBML Level 3 Core "
-    "namespace are permitted on a <objective>.",
+    "namespace are permitted on an <objective>.",
     { "L3V1 Core, Section 3.2"
     }
   },
@@ -411,10 +409,10 @@ static const packageErrorTableEntry fbcErrorTable[] =
     "Invalid attribute found on <objective> object",
     LIBSBML_CAT_GENERAL_CONSISTENCY, 
     LIBSBML_SEV_ERROR,
-    "A <objective> object must have the required attributes 'fbc:id' and "
+    "An <objective> object must have the required attributes 'fbc:id' and "
     "'fbc:type' and may have the optional attribute 'fbc:name'. No other "
     "attributes from the SBML Level 3 Flux Balance Constraints namespace "
-    "are permitted on a <objective> object.",
+    "are permitted on an <objective> object.",
     { "L3V1 Fbc V1, Section 3.6"
     }
   },
@@ -424,7 +422,7 @@ static const packageErrorTableEntry fbcErrorTable[] =
     "The attribute 'fbc:name' must be of the data type string",
     LIBSBML_CAT_GENERAL_CONSISTENCY, 
     LIBSBML_SEV_ERROR,
-    "The attribute 'fbc:name' on a <objective> must be of the data type "
+    "The attribute 'fbc:name' on an <objective> must be of the data type "
     "'string'. ",
     { "L3V1 Fbc V1, Section 3.6"
     }
@@ -435,8 +433,8 @@ static const packageErrorTableEntry fbcErrorTable[] =
     "The attribute 'fbc:type' must be of data type FbcType.",
     LIBSBML_CAT_GENERAL_CONSISTENCY, 
     LIBSBML_SEV_ERROR,
-    "The attribute 'fbc:type' on a <objective> must be of the data type "
-    "FbcType. and thus its value must be "
+    "The attribute 'fbc:type' on an <objective> must be of the data type "
+    "FbcType and thus its value must be "
     "one of 'minimize' or 'maximize.",
     { "L3V1 Fbc V1, Section 3.6"
     }
@@ -447,7 +445,7 @@ static const packageErrorTableEntry fbcErrorTable[] =
     "An <objective> must have one <listOfFluxObjectives>.",
     LIBSBML_CAT_GENERAL_CONSISTENCY, 
     LIBSBML_SEV_ERROR,
-    "A <objective> object must have one and only one instance of the "
+    "An <objective> object must have one and only one instance of the "
     "<listOfFluxObjectives> object. ",
     { "L3V1 Fbc V1, Section 3.6"
     }
@@ -458,7 +456,7 @@ static const packageErrorTableEntry fbcErrorTable[] =
     "<listOfFluxObjectives> subobject must not be empty",
     LIBSBML_CAT_GENERAL_CONSISTENCY, 
     LIBSBML_SEV_ERROR,
-    "The <listOfFluxObjectives> subobject within a <objective> object must "
+    "The <listOfFluxObjectives> subobject within an <objective> object must "
     "not be empty.",
     { "L3V1 Fbc V1, Section 3.6"
     }
