@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ * 
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2004-2008 by European Media Laboratories Research gGmbH,
  *     Heidelberg, Germany
@@ -22,8 +27,7 @@
  * ------------------------------------------------------------------------ -->
  *
  * @class GraphicalObject
- * @sbmlbrief{layout} The basic &ldquo;layout&rdquo; package element for
- * storing layout information.
+ * @sbmlbrief{layout} Base class of objects that store layouts.
  *
  * All the more specific layout elements (CompartmentGlyph, GeneralGlyph,
  * SpeciesGlyph, ReactionGlyph, ReferenceGlyph, TextGlyph, and
@@ -274,12 +278,16 @@ public:
   virtual void writeElements (XMLOutputStream& stream) const;
   /** @endcond */
 
+
   /**
    * Returns the XML element name of
    * this SBML object.
+   *
+   * @return the string of the name of this element
    */
   virtual const std::string& getElementName () const ;
 
+
   /**
    * Creates and returns a deep copy of this GraphicalObject.
    * 
@@ -294,7 +302,7 @@ public:
    * @copydetails doc_what_are_typecodes
    *
    * @return the SBML type code for this object:
-   * @link SBMLLayoutTypeCode_t#SBML_LAYOUT_GRAPHICALOBJECT SBML_LAYOUT_GRAPHICALOBJECT@endlink
+   * @sbmlconstant{SBML_LAYOUT_GRAPHICALOBJECT, SBMLLayoutTypeCode_t}
    *
    * @copydetails doc_warning_typecodes_not_unique
    *
@@ -424,8 +432,7 @@ protected:
 
 /**
  * @class ListOfGraphicalObjects
- * @sbmlbrief{layout} Implementation of the %ListOfAdditionalGraphicalObjects
- * construct from the &ldquo;layout&rdquo; package.
+ * @sbmlbrief{layout} A list of GraphicalObject objects.
  * 
  * The ListOfGraphicalObjects class in libSBML actually represents the
  * ListOfAdditionalGraphicalObjects class in the &ldquo;layout&rdquo;
@@ -469,7 +476,7 @@ public:
    * @copydetails doc_what_are_typecodes
    *
    * @return the SBML type code for objects contained in this list:
-   * @link SBMLTypeCode_t#SBML_LAYOUT_GRAPHICALOBJECT SBML_LAYOUT_GRAPHICALOBJECT@endlink (default).
+   * @sbmlconstant{SBML_LAYOUT_GRAPHICALOBJECT, SBMLTypeCode_t} (default).
    *
    * @see getElementName()
    * @see getPackageName()
@@ -479,9 +486,12 @@ public:
   /**
    * Returns the XML element name of
    * this SBML object.
+   *
+   * @return the string of the name of this element
    */
   virtual const std::string& getElementName () const;
 
+
   /** @cond doxygenLibsbmlInternal */
   /* 
    * Allow overwriting the element name (as used by the generalGlyph)
@@ -610,74 +620,129 @@ LIBSBML_CPP_NAMESPACE_END
 LIBSBML_CPP_NAMESPACE_BEGIN
 BEGIN_C_DECLS
 
-
-
-/*
- * Creates a new GraphicalObject.
+/**
+ * Creates a new GraphicalObject_t.
+ *
+ * @memberof GraphicalObject_t
  */
 LIBSBML_EXTERN
 GraphicalObject_t *
 GraphicalObject_create (void);
 
 
-/*
- * Creates a GraphicalObject from a template.
+/**
+ * Creates a GraphicalObject_t from a template.
+ *
+ * @param temp The GraphicalObject_t structure to copy.
+ *
+ * @memberof GraphicalObject_t
  */
 LIBSBML_EXTERN
 GraphicalObject_t *
 GraphicalObject_createFrom (const GraphicalObject_t *temp);
 
-/*
- * Frees all memory taken up by the GraphicalObject.
+/**
+ * Frees all memory taken up by the GraphicalObject_t.
+ *
+ * @param go The GraphicalObject_t structure.
+ *
+ * @memberof GraphicalObject_t
  */ 
 LIBSBML_EXTERN
 void
 GraphicalObject_free (GraphicalObject_t *go);
 
 
-/*
- * Sets the boundingbox for the GraphicalObject.
+/**
+ * Sets the boundingbox for the GraphicalObject_t.
+ *
+ * @param go The GraphicalObject_t structure.
+ * @param bb The BoundingBox_t structure to use.
+ *
+ * @memberof GraphicalObject_t
  */ 
 LIBSBML_EXTERN
 void
 GraphicalObject_setBoundingBox (GraphicalObject_t *go, const BoundingBox_t *bb);
 
-/*
- * Returns the bounding box for the GraphicalObject.
+/**
+ * Returns the bounding box for the GraphicalObject_t.
+ *
+ * @param go The GraphicalObject_t structure.
+ *
+ * @memberof GraphicalObject_t
  */ 
 LIBSBML_EXTERN
 BoundingBox_t *
 GraphicalObject_getBoundingBox (GraphicalObject_t *go);
 
-/*
- * Does nothing. No defaults are defined for GraphicalObject.
+/**
+ * Does nothing. No defaults are defined for GraphicalObject_t.
+ *
+ * @param go The GraphicalObject_t structure.
+ *
+ * @memberof GraphicalObject_t
  */ 
 LIBSBML_EXTERN
 void
 GraphicalObject_initDefaults (GraphicalObject_t *go);
 
-/*
- * @return a (deep) copy of this GraphicalObject.
+/**
+ * @return a (deep) copy of this GraphicalObject_t.
+ *
+ * @param go The GraphicalObject_t structure.
+ *
+ * @memberof GraphicalObject_t
  */
 LIBSBML_EXTERN
 GraphicalObject_t *
-GraphicalObject_clone (const GraphicalObject_t *m);
+GraphicalObject_clone (const GraphicalObject_t *go);
 
 
+/**
+ * Returns non-zero if the id is set
+ *
+ * @param go The GraphicalObject_t structure.
+ *
+ * @memberof GraphicalObject_t
+ */
 LIBSBML_EXTERN
 int
 GraphicalObject_isSetId (const GraphicalObject_t *go);
 
+
+/**
+ * Returns the id
+ *
+ * @param go The GraphicalObject_t structure.
+ *
+ * @memberof GraphicalObject_t
+ */
 LIBSBML_EXTERN
 const char *
 GraphicalObject_getId (const GraphicalObject_t *go);
 
 
+/**
+ * Sets the id
+ *
+ * @param go The GraphicalObject_t structure.
+ * @param sid The string to use as the ID of the GraphicalObject_t
+ *
+ * @memberof GraphicalObject_t
+ */
 LIBSBML_EXTERN
 int
 GraphicalObject_setId (GraphicalObject_t *go, const char *sid);
 
 
+/**
+ * Unsets the id
+ *
+ * @param go The GraphicalObject_t structure.
+ *
+ * @memberof GraphicalObject_t
+ */
 LIBSBML_EXTERN
 void
 GraphicalObject_unsetId (GraphicalObject_t *go);
