@@ -7,7 +7,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -628,15 +628,15 @@ ReactionGlyph::addExpectedAttributes(ExpectedAttributes& attributes)
 void ReactionGlyph::readAttributes (const XMLAttributes& attributes,
                                     const ExpectedAttributes& expectedAttributes)
 {
-	const unsigned int sbmlLevel   = getLevel  ();
-	const unsigned int sbmlVersion = getVersion();
+  const unsigned int sbmlLevel   = getLevel  ();
+  const unsigned int sbmlVersion = getVersion();
 
-	unsigned int numErrs;
+  unsigned int numErrs;
 
-	/* look to see whether an unknown attribute error was logged
-	 * during the read of the listOfReactionGlyphs - which will have
-	 * happened immediately prior to this read
-	*/
+  /* look to see whether an unknown attribute error was logged
+  * during the read of the listOfReactionGlyphs - which will have
+  * happened immediately prior to this read
+  */
 
   bool loSubGlyphs = false;
   if (getParentSBMLObject() != NULL
@@ -645,99 +645,100 @@ void ReactionGlyph::readAttributes (const XMLAttributes& attributes,
     loSubGlyphs = true;
   }
 
-	if (getErrorLog() != NULL &&
-	    static_cast<ListOfReactionGlyphs*>(getParentSBMLObject())->size() < 2)
-	{
-		numErrs = getErrorLog()->getNumErrors();
-		for (int n = numErrs-1; n >= 0; n--)
-		{
-			if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
-			{
-				const std::string details =
-				      getErrorLog()->getError(n)->getMessage();
-				getErrorLog()->remove(UnknownPackageAttribute);
+  if (getErrorLog() != NULL &&
+    static_cast<ListOfReactionGlyphs*>(getParentSBMLObject())->size() < 2)
+  {
+    numErrs = getErrorLog()->getNumErrors();
+    for (int n = numErrs-1; n >= 0; n--)
+    {
+      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      {
+        const std::string details =
+          getErrorLog()->getError(n)->getMessage();
+        getErrorLog()->remove(UnknownPackageAttribute);
         if (loSubGlyphs == true)
         {
-				  getErrorLog()->logPackageError("layout", 
-                                    LayoutLOSubGlyphAllowedAttribs,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
+          getErrorLog()->logPackageError("layout", 
+            LayoutLOSubGlyphAllowedAttribs,
+            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
         else
         {
-				  getErrorLog()->logPackageError("layout", 
-                                    LayoutLORnGlyphAllowedAttributes,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
+          getErrorLog()->logPackageError("layout", 
+            LayoutLORnGlyphAllowedAttributes,
+            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
-			}
-			else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
-			{
-				const std::string details =
-				           getErrorLog()->getError(n)->getMessage();
-				getErrorLog()->remove(UnknownCoreAttribute);
+      }
+      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      {
+        const std::string details =
+          getErrorLog()->getError(n)->getMessage();
+        getErrorLog()->remove(UnknownCoreAttribute);
         if (loSubGlyphs == true)
         {
-				  getErrorLog()->logPackageError("layout", 
-                                    LayoutLOSubGlyphAllowedAttribs,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
+          getErrorLog()->logPackageError("layout", 
+            LayoutLOSubGlyphAllowedAttribs,
+            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
         else
         {
-				  getErrorLog()->logPackageError("layout", 
-                                    LayoutLORnGlyphAllowedAttributes,
-				            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
+          getErrorLog()->logPackageError("layout", 
+            LayoutLORnGlyphAllowedAttributes,
+            getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
         }
-			}
-		}
-	}
+      }
+    }
+  }
 
-	GraphicalObject::readAttributes(attributes, expectedAttributes);
+  GraphicalObject::readAttributes(attributes, expectedAttributes);
 
-	// look to see whether an unknown attribute error was logged
-	if (getErrorLog() != NULL)
-	{
-		numErrs = getErrorLog()->getNumErrors();
-		for (int n = numErrs-1; n >= 0; n--)
-		{
-			if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
-			{
-				const std::string details =
-				                  getErrorLog()->getError(n)->getMessage();
-				getErrorLog()->remove(UnknownPackageAttribute);
-				getErrorLog()->logPackageError("layout", LayoutRGAllowedAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
-			}
-			else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
-			{
-				const std::string details =
-				                  getErrorLog()->getError(n)->getMessage();
-				getErrorLog()->remove(UnknownCoreAttribute);
-				getErrorLog()->logPackageError("layout", LayoutRGAllowedCoreAttributes,
-				               getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
-			}
-		}
-	}
+  // look to see whether an unknown attribute error was logged
+  if (getErrorLog() != NULL)
+  {
+    numErrs = getErrorLog()->getNumErrors();
+    for (int n = numErrs-1; n >= 0; n--)
+    {
+      if (getErrorLog()->getError(n)->getErrorId() == UnknownPackageAttribute)
+      {
+        const std::string details =
+          getErrorLog()->getError(n)->getMessage();
+        getErrorLog()->remove(UnknownPackageAttribute);
+        getErrorLog()->logPackageError("layout", LayoutRGAllowedAttributes,
+          getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
+      }
+      else if (getErrorLog()->getError(n)->getErrorId() == UnknownCoreAttribute)
+      {
+        const std::string details =
+          getErrorLog()->getError(n)->getMessage();
+        getErrorLog()->remove(UnknownCoreAttribute);
+        getErrorLog()->logPackageError("layout", LayoutRGAllowedCoreAttributes,
+          getPackageVersion(), sbmlLevel, sbmlVersion, details, getLine(), getColumn());
+      }
+    }
+  }
 
-	bool assigned = false;
+  bool assigned = false;
 
-	//
-	// reaction SIdRef   ( use = "optional" )
-	//
-	assigned = attributes.readInto("reaction", mReaction);
+  //
+  // reaction SIdRef   ( use = "optional" )
+  //
+  assigned = attributes.readInto("reaction", mReaction);
 
-	if (assigned == true && getErrorLog() != NULL)
-	{
-		// check string is not empty and correct syntax
+  if (assigned == true && getErrorLog() != NULL)
+  {
+    // check string is not empty and correct syntax
 
-		if (mReaction.empty() == true)
-		{
+    if (mReaction.empty() == true)
+    {
       logEmptyString(mReaction, getLevel(), getVersion(), "<ReactionGlyph>");
-		}
-		else if (SyntaxChecker::isValidSBMLSId(mReaction) == false)
-		{
-			getErrorLog()->logPackageError("layout", LayoutRGReactionSyntax,
-				             getPackageVersion(), sbmlLevel, sbmlVersion, "", getLine(), getColumn());
-		}
-	}
+    }
+    else if (SyntaxChecker::isValidSBMLSId(mReaction) == false)
+    {
+      getErrorLog()->logPackageError("layout", LayoutRGReactionSyntax,
+        getPackageVersion(), sbmlLevel, sbmlVersion, "The reaction on the <" 
+        + getElementName() + "> is '" + mReaction + "', which does not conform to the syntax.", getLine(), getColumn());
+    }
+  }
 
 }
 /** @endcond */
