@@ -979,6 +979,10 @@ MultiSpeciesType::getAllElements(ElementFilter* filter)
   List* ret = new List();
   List* sublist = NULL;
 
+  ADD_FILTERED_LIST(ret, sublist, mSpeciesFeatureTypes, filter);
+  ADD_FILTERED_LIST(ret, sublist, mSpeciesTypeInstances, filter);
+  ADD_FILTERED_LIST(ret, sublist, mSpeciesTypeComponentIndexes, filter);
+  ADD_FILTERED_LIST(ret, sublist, mInSpeciesTypeBonds, filter);
 
   ADD_FILTERED_FROM_PLUGIN(ret, sublist, filter);
 
@@ -1564,6 +1568,18 @@ ListOfMultiSpeciesTypes::writeXMLNS(XMLOutputStream& stream) const
   stream << xmlns;
 }
 
+/*
+ * Return true only when the item is an object of MultiSpeciesType or
+ * BindingSiteSpeciesType
+ */
+bool
+ListOfMultiSpeciesTypes::isValidTypeForList(SBase * item)
+{
+  return item->getTypeCode() == SBML_MULTI_SPECIES_TYPE ||
+      item->getTypeCode() == SBML_MULTI_BINDING_SITE_SPECIES_TYPE;
+}
+
+
 
   /** @endcond doxygenLibsbmlInternal */
 
