@@ -1240,6 +1240,12 @@ protected:
   /** @endcond doxygenLibsbmlInternal */
 
 
+  /**
+   * Override the virtual function in the parent ListOf class. Returns true
+   * if the item is an object of MultiSpeciesType or BindingSiteSpeciesType.
+   */
+  virtual bool isValidTypeForList(SBase * item);
+
 
 };
 
