@@ -9,7 +9,7 @@
  *
  * Copyright (C) 2009-2013 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -30,6 +30,8 @@
 #include <sbml/packages/multi/sbml/SpeciesTypeComponentMapInProduct.h>
 #include <sbml/packages/multi/validator/MultiSBMLError.h>
 
+#include <sbml/util/ElementFilter.h>
+
 
 using namespace std;
 
@@ -462,6 +464,7 @@ SpeciesTypeComponentMapInProduct::createSpeciesFeatureChange()
   {
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     sfc = new SpeciesFeatureChange(multins);
+    delete multins;
   }
   catch (...)
   {
@@ -511,6 +514,7 @@ SpeciesTypeComponentMapInProduct::getAllElements(ElementFilter* filter)
   List* ret = new List();
   List* sublist = NULL;
 
+  ADD_FILTERED_LIST(ret, sublist, mSpeciesFeatureChanges, filter);
 
   ADD_FILTERED_FROM_PLUGIN(ret, sublist, filter);
 
@@ -681,6 +685,7 @@ SpeciesTypeComponentMapInProduct::createObject(XMLInputStream& stream)
     object = &mSpeciesFeatureChanges;
   }
 
+  delete multins;
   return object;
 }
 
@@ -793,9 +798,9 @@ SpeciesTypeComponentMapInProduct::readAttributes (const XMLAttributes& attribute
     {
       logEmptyString(mReactant, getLevel(), getVersion(), "<SpeciesTypeComponentMapInProduct>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mReactant) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mReactant) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute reactant='" + mReactant + "' does not conform.");
     }
   }
@@ -819,9 +824,9 @@ SpeciesTypeComponentMapInProduct::readAttributes (const XMLAttributes& attribute
     {
       logEmptyString(mReactantComponent, getLevel(), getVersion(), "<SpeciesTypeComponentMapInProduct>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mReactantComponent) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mReactantComponent) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute reactantComponent='" + mReactantComponent 
         + "' does not conform.");
     }
@@ -846,9 +851,9 @@ SpeciesTypeComponentMapInProduct::readAttributes (const XMLAttributes& attribute
     {
       logEmptyString(mProductComponent, getLevel(), getVersion(), "<SpeciesTypeComponentMapInProduct>");
     }
-    else if (SyntaxChecker::isValidSBMLSId(mProductComponent) == false)
+    else if (SyntaxChecker::isValidSBMLSId(mProductComponent) == false && getErrorLog() != NULL)
     {
-      logError(InvalidIdSyntax, getLevel(), getVersion(), 
+      getErrorLog()->logError(InvalidIdSyntax, getLevel(), getVersion(), 
         "The syntax of the attribute productComponent='" + mProductComponent 
         + "' does not conform.");
     }
@@ -1047,6 +1052,7 @@ ListOfSpeciesTypeComponentMapInProducts::createObject(XMLInputStream& stream)
     MULTI_CREATE_NS(multins, getSBMLNamespaces());
     object = new SpeciesTypeComponentMapInProduct(multins);
     appendAndOwn(object);
+    delete multins;
   }
 
   return object;
@@ -1070,7 +1076,8 @@ ListOfSpeciesTypeComponentMapInProducts::writeXMLNS(XMLOutputStream& stream) con
 
   if (prefix.empty())
   {
-    if (getNamespaces()->hasURI(MultiExtension::getXmlnsL3V1V1()))
+    XMLNamespaces* thisxmlns = getNamespaces();
+    if (thisxmlns && thisxmlns->hasURI(MultiExtension::getXmlnsL3V1V1()))
     {
       xmlns.add(MultiExtension::getXmlnsL3V1V1(),prefix);
     }
