@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -346,8 +346,22 @@ ArgumentsUnitsCheck::getMessage (const ASTNode& node, const SBase& object)
   //msg << getPreamble();
   char * formula = SBML_formulaToString(&node);
   msg << "The formula '" << formula;
-  msg << "' in the " << getFieldname() << " element of the " << getTypename(object);
-  msg << " produces an exponent that is not an integer and thus may produce ";
+  msg << "' in the " << getFieldname() << " element of the <" << object.getElementName();
+  msg << "> ";
+  switch(object.getTypeCode()) {
+  case SBML_INITIAL_ASSIGNMENT:
+  case SBML_EVENT_ASSIGNMENT:
+  case SBML_ASSIGNMENT_RULE:
+  case SBML_RATE_RULE:
+    //LS DEBUG:  could use other attribute values, or 'isSetActualId'.
+    break;
+  default:
+    if (object.isSetId()) {
+      msg << "with id '" << object.getId() << "' ";
+    }
+    break;
+  }
+  msg << "produces an exponent that is not an integer and thus may produce ";
   msg << "invalid units.";
   safe_free(formula);
 
@@ -364,9 +378,24 @@ ArgumentsUnitsCheck::logInconsistentSameUnits (const ASTNode & node,
   char * formula = SBML_formulaToString(&node);
   msg = "The formula '" ;
   msg += formula;
-  msg += "' in the math element of the ";
-  msg += getTypename(sb);
-  msg += " can only act on variables with the same units.";
+  msg += "' in the math element of the <";
+  msg += sb.getElementName();
+  msg += "> ";
+  switch(sb.getTypeCode()) {
+  case SBML_INITIAL_ASSIGNMENT:
+  case SBML_EVENT_ASSIGNMENT:
+  case SBML_ASSIGNMENT_RULE:
+  case SBML_RATE_RULE:
+    //LS DEBUG:  could use other attribute values, or 'isSetActualId'.
+    break;
+  default:
+    if (sb.isSetId()) {
+      msg += "with id '";
+      msg += getId() + "' ";
+    }
+    break;
+  }
+  msg += "can only act on variables with the same units.";
   safe_free(formula);
 
   logFailure(sb, msg);
@@ -381,11 +410,26 @@ ArgumentsUnitsCheck::logInconsistentDelay (const ASTNode & node,
                                           const SBase & sb)
 {
   char * formula = SBML_formulaToString(&node);
-  msg = "The formula ";
+  msg = "The formula '";
   msg += formula;
-  msg += "' in the math element of the ";
-  msg += getTypename(sb);
-  msg += " uses a delay function";
+  msg += "' in the math element of the <";
+  msg += sb.getElementName();
+  msg += "> ";
+  switch(sb.getTypeCode()) {
+  case SBML_INITIAL_ASSIGNMENT:
+  case SBML_EVENT_ASSIGNMENT:
+  case SBML_ASSIGNMENT_RULE:
+  case SBML_RATE_RULE:
+    //LS DEBUG:  could use other attribute values, or 'isSetActualId'.
+    break;
+  default:
+    if (sb.isSetId()) {
+      msg += "with id '";
+      msg += getId() + "' ";
+    }
+    break;
+  }
+  msg += "uses a delay function";
   msg += " with a delta t value that does not have units of time.";
   safe_free(formula);
 
@@ -401,11 +445,26 @@ ArgumentsUnitsCheck::logInconsistentPiecewise (const ASTNode & node,
                                           const SBase & sb)
 {
   char * formula = SBML_formulaToString(&node);
-  msg = "The formula ";
+  msg = "The formula '";
   msg += formula;
-  msg += "' in the math element of the ";
-  msg += getTypename(sb);
-  msg += " uses a piecewise function";
+  msg += "' in the math element of the <";
+  msg += sb.getElementName();
+  msg += "> ";
+  switch(sb.getTypeCode()) {
+  case SBML_INITIAL_ASSIGNMENT:
+  case SBML_EVENT_ASSIGNMENT:
+  case SBML_ASSIGNMENT_RULE:
+  case SBML_RATE_RULE:
+    //LS DEBUG:  could use other attribute values, or 'isSetActualId'.
+    break;
+  default:
+    if (sb.isSetId()) {
+      msg += "with id '";
+      msg += getId() + "' ";
+    }
+    break;
+  }
+  msg += "uses a piecewise function";
   msg += " where different branches return different units.";
   safe_free(formula);
 
@@ -424,9 +483,24 @@ ArgumentsUnitsCheck::logInconsistentPiecewiseCondition (const ASTNode & node,
   char * formula = SBML_formulaToString(&node);
   msg = "The formula '";
   msg += formula;
-  msg += "' in the math element of the ";
-  msg += getTypename(sb);
-  msg += " uses a piecewise function";
+  msg += "' in the math element of the <";
+  msg += sb.getElementName();
+  msg += "> ";
+  switch(sb.getTypeCode()) {
+  case SBML_INITIAL_ASSIGNMENT:
+  case SBML_EVENT_ASSIGNMENT:
+  case SBML_ASSIGNMENT_RULE:
+  case SBML_RATE_RULE:
+    //LS DEBUG:  could use other attribute values, or 'isSetActualId'.
+    break;
+  default:
+    if (sb.isSetId()) {
+      msg += "with id '";
+      msg += getId() + "' ";
+    }
+    break;
+  }
+  msg += "uses a piecewise function";
   msg += " where the conditional statement is not dimensionless.";
   safe_free(formula);
 
