@@ -9,7 +9,7 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
- * Copyright (C) 2013-2014 jointly by the following organizations:
+ * Copyright (C) 2013-2015 jointly by the following organizations:
  *     1. California Institute of Technology, Pasadena, CA, USA
  *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *     3. University of Heidelberg, Heidelberg, Germany
@@ -284,8 +284,22 @@ ExponentUnitsCheck::getMessage (const ASTNode& node, const SBase& object)
 
   char * formula = SBML_formulaToString(&node);
   msg << "The formula '" << formula;
-  msg << "' in the " << getFieldname() << " element of the " << getTypename(object);
-  msg << " produces an exponent that is not an integer and thus may produce ";
+  msg << "' in the " << getFieldname() << " element of the <" << object.getElementName();
+  msg << "> ";
+  switch(object.getTypeCode()) {
+  case SBML_INITIAL_ASSIGNMENT:
+  case SBML_EVENT_ASSIGNMENT:
+  case SBML_ASSIGNMENT_RULE:
+  case SBML_RATE_RULE:
+    //LS DEBUG:  could use other attribute values, or 'isSetActualId'.
+    break;
+  default:
+    if (object.isSetId()) {
+      msg << "with id '" << object.getId() << "' ";
+    }
+    break;
+  }
+  msg << "produces an exponent that is not an integer and thus may produce ";
   msg << "invalid units.";
   safe_free(formula);
 
@@ -301,9 +315,23 @@ ExponentUnitsCheck::logRationalPowerConflict (const ASTNode & node,
   msg += formula;
   msg += "' in the ";
   msg += getFieldname();
-  msg += " element of the " ;
-  msg += getTypename(sb);
-  msg += " contains a rational power that is inconsistent and thus may produce ";
+  msg += " element of the <" + sb.getElementName();
+  msg += "> ";
+  switch(sb.getTypeCode()) {
+  case SBML_INITIAL_ASSIGNMENT:
+  case SBML_EVENT_ASSIGNMENT:
+  case SBML_ASSIGNMENT_RULE:
+  case SBML_RATE_RULE:
+    //LS DEBUG:  could use other attribute values, or 'isSetActualId'.
+    break;
+  default:
+    if (sb.isSetId()) {
+      msg += "with id '";
+      msg += sb.getId() + "' ";
+    }
+    break;
+  }
+  msg += "contains a rational power that is inconsistent and thus may produce ";
   msg += "invalid units.";
   safe_free(formula);
 
@@ -320,9 +348,23 @@ ExponentUnitsCheck::logNonIntegerPowerConflict (const ASTNode & node,
   msg += formula;
   msg += "' in the ";
   msg += getFieldname();
-  msg += " element of the " ;
-  msg += getTypename(sb);
-  msg += " contains a root that is not an integer and thus may produce ";
+  msg += " element of the <" + sb.getElementName();
+  msg += "> ";
+  switch(sb.getTypeCode()) {
+  case SBML_INITIAL_ASSIGNMENT:
+  case SBML_EVENT_ASSIGNMENT:
+  case SBML_ASSIGNMENT_RULE:
+  case SBML_RATE_RULE:
+    //LS DEBUG:  could use other attribute values, or 'isSetActualId'.
+    break;
+  default:
+    if (sb.isSetId()) {
+      msg += "with id '";
+      msg += sb.getId() + "' ";
+    }
+    break;
+  }
+  msg += "contains a root that is not an integer and thus may produce ";
   msg += "invalid units.";
   safe_free(formula);
 
