@@ -7,9 +7,14 @@
  * This file is part of libSBML.  Please visit http://sbml.org for more
  * information about SBML, and the latest version of libSBML.
  *
+ * Copyright (C) 2013-2015 jointly by the following organizations:
+ *     1. California Institute of Technology, Pasadena, CA, USA
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
+ *     3. University of Heidelberg, Heidelberg, Germany
+ *
  * Copyright (C) 2009-2013 jointly by the following organizations: 
  *     1. California Institute of Technology, Pasadena, CA, USA
- *     2. EMBL European Bioinformatics Institute (EBML-EBI), Hinxton, UK
+ *     2. EMBL European Bioinformatics Institute (EMBL-EBI), Hinxton, UK
  *  
  * Copyright (C) 2006-2008 by the California Institute of Technology,
  *     Pasadena, CA, USA 
@@ -339,13 +344,14 @@ XMLError::XMLError (  const int errorId
       if ( errorTable[i].code == errorId )
       {
         mMessage      = errorTable[i].message;
-	      mShortMessage = errorTable[i].shortMessage;
+        mShortMessage = errorTable[i].shortMessage;
 
         if ( &details != NULL && !details.empty() )
         {
           mMessage.append(" ");
           mMessage.append(details);
         }
+        mMessage += "\n";
 
         mSeverity = errorTable[i].severity;
         mCategory = errorTable[i].category;
@@ -372,12 +378,14 @@ XMLError::XMLError (  const int errorId
     // Now we log the error as an UnKnown Error and mark it as invalid
 
     mMessage      = errorTable[0].message;
+    mMessage += "\n";
     mShortMessage = errorTable[0].shortMessage;
 
     if ( &details != NULL && !details.empty() )
     {
       mMessage.append(" ");
       mMessage.append(details);
+      mMessage.append("\n");
     }
 
     mSeverity = LIBSBML_SEV_WARNING;
@@ -811,12 +819,9 @@ ostream& operator<< (ostream& s, const XMLError& error)
 
 
 #endif /* __cplusplus */
-/** @cond doxygenCOnly */
+/** @cond doxygenIgnored */
 
 
-/**
- * Creates a new XMLError to report that something occurred.
- */
 LIBLAX_EXTERN
 XMLError_t*
 XMLError_create (void)
@@ -825,17 +830,6 @@ XMLError_create (void)
 }
 
 
-/**
- * Creates a new XMLError with the identification number
- * and detailed message set.
- *
- * If the identifier is < 10000, it must be one of the predefined XML layer
- * error codes.
- *
- * @param errorId an unsigned int, the identification number of the error.
- * @param message a string, the error message.
- *
- */
 LIBLAX_EXTERN
 XMLError_t*
 XMLError_createWithIdAndMessage (unsigned int errorId, const char * message)
@@ -844,19 +838,6 @@ XMLError_createWithIdAndMessage (unsigned int errorId, const char * message)
   return new(nothrow) XMLError(errorId, message);
 }
 
-/*
- * Creates a new XMLError to report that something occurred at the given
- * line and column.  Each XMLError also has an identification number, a
- * category, and a severity level associated with it.
- *
- * @param errorId an unsigned int, the identification number of the error.
- * @param message a string, the error message.
- * @param severity XMLErrorSeverity_t, severity of the error.
- * @param category a string, the category to which the error belongs.
- * @param line an unsigned int, the line number at which the error occurs.
- * @param column an unsigned int, the column number at which the error occurs.
- *
- */
 //LIBLAX_EXTERN
 //XMLError_t*
 //XMLError_createWithAll (unsigned int errorId, const char * message, XMLError_Severity severity,
@@ -885,11 +866,6 @@ XMLError_createWithIdAndMessage (unsigned int errorId, const char * message)
 //}
 
 
-/**
- * Frees the given XMLError_t structure.
- *
- * @param error the XMLError_t structure to be freed.
- **/
 LIBLAX_EXTERN
 void
 XMLError_free(XMLError_t* error)
@@ -898,13 +874,6 @@ XMLError_free(XMLError_t* error)
   delete static_cast<XMLError*>(error);
 }
 
-/**
- * Returns the id of this XMLError.
- *
- * @param error the XMLError_t from which to return the id.
- *
- * @return the id of this XMLError.
- */
 LIBLAX_EXTERN
 unsigned int
 XMLError_getErrorId (const XMLError_t *error)
@@ -914,13 +883,6 @@ XMLError_getErrorId (const XMLError_t *error)
 }
 
 
-/**
- * Returns the message text of this XMLError.
- *
- * @param error the XMLError_t from which to return the message.
- *
- * @return the message text of this XMLError.
- */
 LIBLAX_EXTERN
 const char *
 XMLError_getMessage (const XMLError_t *error)
@@ -930,13 +892,6 @@ XMLError_getMessage (const XMLError_t *error)
 }
 
 
-/**
- * Returns the short message text of this XMLError.
- *
- * @param error the XMLError_t from which to return the short message.
- *
- * @return the message text of this XMLError.
- */
 LIBLAX_EXTERN
 const char *
 XMLError_getShortMessage (const XMLError_t *error)
@@ -946,13 +901,6 @@ XMLError_getShortMessage (const XMLError_t *error)
 }
 
 
-/**
- * Return the line number where this XMLError occurred.
- *
- * @param error the XMLError_t from which to return the line number.
- *
- * @return the line number where this XMLError occurred.
- */
 LIBLAX_EXTERN
 unsigned int
 XMLError_getLine (const XMLError_t *error)
@@ -962,13 +910,6 @@ XMLError_getLine (const XMLError_t *error)
 }
 
 
-/**
- * Return the column number where this XMLError occurred.
- *
- * @param error the XMLError_t from which to return the column number.
- *
- * @return the column number where this XMLError occurred.
- */
 LIBLAX_EXTERN
 unsigned int
 XMLError_getColumn (const XMLError_t *error)
@@ -978,14 +919,6 @@ XMLError_getColumn (const XMLError_t *error)
 }
 
 
-/**
- * Return the severity of this XMLError.  The possible values (for the XML
- * layer) are those from the enumeration XMLErrorSeverity_t.
- *
- * @param error the XMLError_t from which to return the severity.
- *
- * @return the severity of this XMLError.
- */
 LIBLAX_EXTERN
 unsigned int
 XMLError_getSeverity (const XMLError_t *error)
@@ -995,13 +928,6 @@ XMLError_getSeverity (const XMLError_t *error)
 }
 
 
-/**
- * Return the severity of this XMLError as a string.erity_t.
- *
- * @param error the XMLError_t from which to return the severity.
- *
- * @return string representing the severity of this XMLError.
- */
 LIBLAX_EXTERN
 const char *
 XMLError_getSeverityAsString (const XMLError_t *error)
@@ -1012,14 +938,6 @@ XMLError_getSeverityAsString (const XMLError_t *error)
 }
 
 
-/**
- * Return the category of this XMLError.  The possible values (for the XML
- * layers) are those from the enumeration XMLErrorCategory_t.
- *
- * @param error the XMLError_t from which to return the category.
- *
- * @return the category of this XMLError.
- */
 LIBLAX_EXTERN
 unsigned int
 XMLError_getCategory (const XMLError_t *error)
@@ -1029,13 +947,6 @@ XMLError_getCategory (const XMLError_t *error)
 }
 
 
-/**
- * Return the category of this XMLError as a string.
- *
- * @param error the XMLError_t from which to return the category.
- *
- * @return string representing the category of this XMLError.
- */
 LIBLAX_EXTERN
 const char *
 XMLError_getCategoryAsString (const XMLError_t *error)
@@ -1046,15 +957,6 @@ XMLError_getCategoryAsString (const XMLError_t *error)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether 
- * this XMLError_t structure is for information only.
- *
- * @param error the XMLError_t.
- *
- * @return @c non-zero (true) if this XMLError is for informational purposes
- * only, @c zero (false) otherwise.
- */
 LIBLAX_EXTERN
 int
 XMLError_isInfo (const XMLError_t *error)
@@ -1064,14 +966,6 @@ XMLError_isInfo (const XMLError_t *error)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether 
- * this XMLError_t structure is a warning.
- *
- * @param error the XMLError_t.
- *
- * @return @c non-zero (true) if this XMLError is a warning, @c zero (false) otherwise.
- */
 LIBLAX_EXTERN
 int
 XMLError_isWarning (const XMLError_t *error)
@@ -1081,14 +975,6 @@ XMLError_isWarning (const XMLError_t *error)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether 
- * this XMLError_t structure is an error.
- *
- * @param error the XMLError_t.
- *
- * @return @c non-zero (true) if this XMLError is an error, @c zero (false) otherwise.
- */
 LIBLAX_EXTERN
 int
 XMLError_isError (const XMLError_t *error)
@@ -1098,14 +984,6 @@ XMLError_isError (const XMLError_t *error)
 }
 
 
-/**
- * Predicate returning @c true or @c false depending on whether 
- * this XMLError_t structure is a fatal error.
- *
- * @param error the XMLError_t.
- *
- * @return @c non-zero (true) if this XMLError is a fatal error, @c zero (false) otherwise.
- */
 LIBLAX_EXTERN
 int
 XMLError_isFatal (const XMLError_t *error)
@@ -1115,15 +993,6 @@ XMLError_isFatal (const XMLError_t *error)
 }
 
 
-/**
- * Outputs this XMLError to stream in the following format (and
- * followed by a newline):
- *
- *   line: (id) message
- *
- * @param error the XMLError_t structure to write.
- * @param stream the stream to write to.
- */
 LIBLAX_EXTERN
 void
 XMLError_print (const XMLError_t *error, FILE *stream)
